<?php
/**
 * Plugin Name: EWD Premium Helper
 * Plugin URI: https://www.etoilewebdesign.com/upgrading-to-premium/
 * Description: Allows a website to access the premium trial and unlocks premium features of Etoile Web Design plugins with an upgrade code
 * Version: 0.0.31
 * Author: Etoile Web Design
 * Author URI: https://profiles.wordpress.org/etoilewebdesign/
 * Text Domain: ewd-premium-helper
 */
if ( ! defined( 'ABSPATH' ) )
	exit;

if ( !class_exists( 'ewdPremiumHelper' ) ) {
class ewdPremiumHelper {

	/**
	 * Initialize the plugin and register hooks
	 */
	public function __construct() {

		// Common strings
		define( 'EWDPH_VERSION', '0.0.31' );
		define( 'EWDPH_PLUGIN_DIR', untrailingslashit( plugin_dir_path( __FILE__ ) ) );
		define( 'EWDPH_PLUGIN_URL', untrailingslashit( plugins_url( basename( plugin_dir_path( __FILE__ ) ), basename( __FILE__ ) ) ) );
		define( 'EWDPH_PLUGIN_FNAME', plugin_basename( __FILE__ ) );

		register_deactivation_hook( EWDPH_PLUGIN_FNAME, array( $this, 'register_deactivation') );

		// Load form adding class
		require_once( EWDPH_PLUGIN_DIR . '/includes/DashboardForms.class.php' );
		new ewdDashboardForms();

		// Load upgrade class
		require_once( EWDPH_PLUGIN_DIR . '/includes/Upgrade.class.php' );
		new ewdHandleUpgrades();

		// Load version reversion class
		require_once( EWDPH_PLUGIN_DIR . '/includes/VersionReversion.class.php' );
		new ewdHandleVersionReversion();

		// Load update class
		require_once( EWDPH_PLUGIN_DIR . '/includes/Updates.class.php' );
		new ewdHandleUpdates();

		// Load helper functions
		require_once( EWDPH_PLUGIN_DIR . '/includes/template-functions.php' );

		// Initialize the plugin
		add_action( 'init', array( $this, 'load_textdomain' ) );

		// Extend OTP with premium features if validated
		add_action( 'ewd_otp_initialized', array( $this, 'extend_ewd_otp_plugin' ) );

		// Extend UASP with premium features if validated
		add_action( 'ewd_uasp_initialized', array( $this, 'extend_ewd_uasp_plugin' ) );

		// Extend UFAQ with premium features if validated
		add_action( 'ewd_ufaq_initialized', array( $this, 'extend_ewd_ufaq_plugin' ) );

		// Extend UPCP with premium features if validated
		add_action( 'ewd_upcp_initialized', array( $this, 'extend_ewd_upcp_plugin' ) );

		// Extend URP with premium features if validated
		add_action( 'ewd_urp_initialized', array( $this, 'extend_ewd_urp_plugin' ) );

		// Extend US with premium features if validated
		add_action( 'ewd_us_initialized', array( $this, 'extend_ewd_us_plugin' ) );

		// Extend UWCF with premium features if validated
		add_action( 'ewd_uwcf_initialized', array( $this, 'extend_ewd_uwcf_plugin' ) );

		// Extend UWPM with premium features if validated
		add_action( 'ewd_uwpm_initialized', array( $this, 'extend_ewd_uwpm_plugin' ) );
	}

	/**
	 * Load the plugin textdomain for localistion
	 * @since 0.0.1
	 */
	public function load_textdomain() {
		load_plugin_textdomain( 'ewd-premium-helper', false, plugin_basename( dirname( __FILE__ ) ) . "/languages/" );
	}

	/**
	 * Add links to the plugin listing on the installed plugins page
	 * @since 0.0.1
	 */
	public function plugin_action_links( $links, $plugin ) {

		if ( $plugin == EWDPH_PLUGIN_FNAME ) {

			$links['help'] = '<a href="https://www.etoilewebdesign.com/premium-upgrade-instructions/" title="' . __( 'View detailed instructions on how to upgrade.', 'ewd-premium-helper' ) . '">' . __( 'Help Upgrading', 'ewd-premium-helper' ) . '</a>';
		}

		return $links;
	}

	public function register_deactivation() {

		// Load version reversion class
		require_once( EWDPH_PLUGIN_DIR . '/includes/VersionReversion.class.php' );
		$version_reversion = new ewdHandleVersionReversion();

		$version_reversion->ewd_plugin_deactivation_reversion();
	}

	public function extend_ewd_otp_plugin() {
		global $ewd_otp_controller;
		
		if ( ! is_object( $ewd_otp_controller ) ) { return; }

		require_once( EWDPH_PLUGIN_DIR . '/includes/otp/Setup.class.php' );

		new ewdotpEWDPHSetup();
	}

	public function extend_ewd_uasp_plugin() {
		global $ewd_uasp_controller;

		if ( ! is_object( $ewd_uasp_controller ) ) { return; }

		require_once( EWDPH_PLUGIN_DIR . '/includes/uasp/Setup.class.php' );

		new ewduaspEWDPHSetup();
	}

	public function extend_ewd_ufaq_plugin() {
		global $ewd_ufaq_controller;

		if ( ! is_object( $ewd_ufaq_controller ) ) { return; }

		require_once( EWDPH_PLUGIN_DIR . '/includes/ufaq/Setup.class.php' );

		new ewdufaqEWDPHSetup();
	}

	public function extend_ewd_upcp_plugin() {
		global $ewd_upcp_controller;

		if ( ! is_object( $ewd_upcp_controller ) ) { return; }

		require_once( EWDPH_PLUGIN_DIR . '/includes/upcp/Setup.class.php' );

		new ewdupcpEWDPHSetup();
	}

	public function extend_ewd_urp_plugin() {
		global $ewd_urp_controller;

		if ( ! is_object( $ewd_urp_controller ) ) { return; }

		require_once( EWDPH_PLUGIN_DIR . '/includes/urp/Setup.class.php' );

		new ewdurpEWDPHSetup();
	}

	public function extend_ewd_us_plugin() {
		global $ewd_us_controller;

		if ( ! is_object( $ewd_us_controller ) ) { return; }

		require_once( EWDPH_PLUGIN_DIR . '/includes/us/Setup.class.php' );

		new ewdusEWDPHSetup();
	}

	public function extend_ewd_uwcf_plugin() {
		global $ewd_uwcf_controller;

		if ( ! is_object( $ewd_uwcf_controller ) ) { return; }

		require_once( EWDPH_PLUGIN_DIR . '/includes/uwcf/Setup.class.php' );

		new ewduwcfEWDPHSetup();
	}
	
	public function extend_ewd_uwpm_plugin() {
		global $ewd_uwpm_controller;

		if ( ! is_object( $ewd_uwpm_controller ) ) { return; }

		require_once( EWDPH_PLUGIN_DIR . '/includes/uwpm/Setup.class.php' );

		new ewduwpmEWDPHSetup();
	}

}
} // endif;

global $ewd_premium_helper;
$ewd_premium_helper = new ewdPremiumHelper();

