<?php
if ( ! defined( 'ABSPATH' ) ) exit;

if ( !class_exists( 'ewdotpEWDPHSettings' ) ) {
class ewdotpEWDPHSettings {

  public function __construct() {
    
    add_filter( 'ewd_otp_defaults', array( $this, 'ewd_otp_settings_set_defaults' ), 10, 2 );

    add_filter( 'ewd_otp_settings_page', array( $this, 'ewd_otp_settings__non_premium_tabs' ), 10, 2 );

    add_filter( 'ewd_otp_settings_page', array( $this, 'ewd_otp_settings_premium_tab' ), 10, 2 );
    add_filter( 'ewd_otp_settings_page', array( $this, 'ewd_otp_settings_locations_tab' ), 10, 2 );
    add_filter( 'ewd_otp_settings_page', array( $this, 'ewd_otp_settings_notifications_tab' ), 10, 2 );
    add_filter( 'ewd_otp_settings_page', array( $this, 'ewd_otp_settings_payments_tab' ), 10, 2 );
    add_filter( 'ewd_otp_settings_page', array( $this, 'ewd_otp_settings_woocommerce_tab' ), 10, 2 );
    add_filter( 'ewd_otp_settings_page', array( $this, 'ewd_otp_settings_zendesk_tab' ), 10, 2 );
    add_filter( 'ewd_otp_settings_page', array( $this, 'ewd_otp_settings_labelling_tab' ), 10, 2 );
    add_filter( 'ewd_otp_settings_page', array( $this, 'ewd_otp_settings_styling_tab' ), 10, 2 );

    add_filter( 'ewd_otp_notification_options', array( $this, 'add_sms_message_options_to_notifications' ), 10, 2 );
  }

  public function get_permission( $permission_type = '' ) {
    global $ewd_otp_controller;
  
    $ewd_otp_premium_permissions = array();
  
    if ( ! $ewd_otp_controller->permissions->check_permission( $permission_type ) ) {
      $ewd_otp_premium_permissions = array(
        'disabled'    => true,
        'disabled_image'=> '#',
        'purchase_link' => 'https://www.etoilewebdesign.com/plugins/order-tracking/?utm_source=otp_lockbox'
      );
    }
  
    return $ewd_otp_premium_permissions;
  }

  public function ewd_otp_settings_set_defaults( $defaults, $ewdotpSettings ) {

    $defaults = array_merge(
      $defaults,
      array(
        // Any default which you are certain that won't be used for free version.
      )
    );
  
    return $defaults;
  }

  public function ewd_otp_settings__non_premium_tabs( $sap, $ewdotpSettings ) {

    return $sap;
  }

  // "Premium" Tab
  public function ewd_otp_settings_premium_tab( $sap, $ewdotpSettings ) {
    
    $sap->add_section(
      'ewd-otp-settings',
      array_merge(
        array(
          'id'            => 'ewd-otp-premium-general',
          'title'         => __( 'General', 'order-tracking' ),
          'tab'         => 'ewd-otp-premium-tab',
        ),
        $this->get_permission( 'premium' )
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-premium-general',
      'select',
      array(
        'id'            => 'access-role',
        'title'         => __( 'Set Access Role', 'order-tracking' ),
        'description'   => __( 'Who should have access to the "Order Tracking" admin menu?', 'order-tracking' ), 
        'blank_option'  => false,
        'options'       => array(
          'administrator'       => __( 'Administrator', 'order-tracking' ),
          'delete_others_pages'   => __( 'Editor', 'order-tracking' ),
          'delete_published_posts'  => __( 'Author', 'order-tracking' ),
          'delete_posts'        => __( 'Contributor', 'order-tracking' ),
        )
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-premium-general',
      'radio',
      array(
        'id'      => 'tracking-graphic',
        'title'     => __( 'Status Tracking Graphic', 'order-tracking' ),
        'description' => __( 'Which tracking graphic should be displayed, if the graphic is being used for your orders.', 'order-tracking' ),
        'options'   => array(
          'default'   => __( 'Default', 'order-tracking' ),
          'streamlined' => __( 'Streamlined', 'order-tracking' ),
          'sleek'     => __( 'Sleek', 'order-tracking' ),
          'minimalist'  => __( 'Minimalist', 'order-tracking' ),
          'round'     => __( 'Round', 'order-tracking' ),
        )
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-premium-general',
      'select',
      array(
        'id'            => 'customer-notes-email',
        'title'         => __( 'Customer Notes Notification', 'order-tracking' ),
        'description'   => __( 'What notification, if any, should be sent to the administrator when the customer note on an order is updated?', 'order-tracking' ), 
        'blank_option'  => true,
        'options'       => isset( $ewdotpSettings->notification_options ) ? $ewdotpSettings->notification_options : $ewdotpSettings->email_options
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-premium-general',
      'toggle',
      array(
        'id'      => 'allow-customer-downloads',
        'title'     => __( 'Allow Customer Downloads', 'order-tracking' ),
        'description' => __( 'Should customers be able to download all of the information on their orders as a CSV file?', 'order-tracking' )
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-premium-general',
      'toggle',
      array(
        'id'      => 'allow-sales-rep-downloads',
        'title'     => __( 'Allow Sales Rep Downloads', 'order-tracking' ),
        'description' => __( 'Should sales reps be able to download all of the information on their orders as a CSV file?', 'order-tracking' )
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-premium-general',
      'toggle',
      array(
        'id'      => 'sales-rep-status-notifications',
        'title'     => __( 'Sales Reps Status Notifications', 'order-tracking' ),
        'description' => __( 'Should sales reps be notified when the status is updated for one of their orders?', 'order-tracking' )
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-premium-general',
      'select',
      array(
        'id'            => 'sales-rep-status-email',
        'title'         => __( 'Sales Rep Status Email', 'order-tracking' ),
        'description'   => __( 'What email should be sent to a sales rep when the status of one of their orders is updated?', 'order-tracking' ), 
        'blank_option'  => true,
        'options'       => isset( $ewdotpSettings->notification_options ) ? $ewdotpSettings->notification_options : $ewdotpSettings->email_options,
        'conditional_on'    => 'sales-rep-status-notifications',
        'conditional_on_value'  => 'true'
      )
    );

    $sap->add_section(
      'ewd-otp-settings',
      array_merge(
        array(
          'id'            => 'ewd-otp-customer-order-form',
          'title'         => __( 'Customer Order Form', 'order-tracking' ),
          'tab'         => 'ewd-otp-premium-tab',
        ),
        $this->get_permission( 'premium' )
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-customer-order-form',
      'select',
      array(
        'id'            => 'customer-order-email',
        'title'         => __( 'Customer Order Notification', 'order-tracking' ),
        'description'   => __( 'What notification, if any, should be sent to the administrator when a new customer order is created?', 'order-tracking' ), 
        'blank_option'  => true,
        'options'       => isset( $ewdotpSettings->notification_options ) ? $ewdotpSettings->notification_options : $ewdotpSettings->email_options
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-customer-order-form',
      'select',
      array(
        'id'            => 'default-customer-order-form-status',
        'title'         => __( 'Default Order Status', 'order-tracking' ),
        'description'   => __( 'What status, if any, should an order be set to after when a customer submits one?', 'order-tracking' ), 
        'blank_option'  => true,
        'options'       => isset( $ewdotpSettings->status_options ) ? $ewdotpSettings->status_options : ''
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-customer-order-form',
      'toggle',
      array(
        'id'      => 'allow-sales-rep-selection',
        'title'     => __( 'Allow Sales Rep Selection', 'order-tracking' ),
        'description' => __( 'Should an option to choose a sales rep be included in the customer order form?', 'order-tracking' )
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-customer-order-form',
      'toggle',
      array(
        'id'      => 'allow-assign-orders-to-customers',
        'title'     => __( 'Assign Orders to Customers', 'order-tracking' ),
        'description' => __( 'With this enabled, orders submitted using the customer order form and imported via the admin will be automatically assigned to a customer based on their email address.', 'order-tracking' )
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-customer-order-form',
      'text',
      array(
        'id'            => 'customer-order-number-prefix',
        'title'         => __( 'Order Number Prefix', 'order-tracking' ),
        'description' => __( 'Specify a prefix for the auto-generated order number for orders created using the customer order form', 'order-tracking' ),
        'small'     => true
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-customer-order-form',
      'text',
      array(
        'id'            => 'customer-order-number-suffix',
        'title'         => __( 'Order Number Suffix', 'order-tracking' ),
        'description' => __( 'Specify a suffix for the auto-generated order number for orders created using the customer order form', 'order-tracking' ),
        'small'     => true
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-customer-order-form',
      'select',
      array(
        'id'            => 'default-sales-rep',
        'title'         => __( 'Default Sales Rep', 'order-tracking' ),
        'description'   => __( 'Choose a default sales rep for all orders created using the customer order form (if not using the above option to enable sales rep selection).', 'order-tracking' ), 
        'blank_option'  => true,
        'options'       => $ewdotpSettings->sales_rep_options
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-customer-order-form',
      'toggle',
      array(
        'id'          => 'use-captcha',
        'title'       => __( 'Captcha', 'order-tracking' ),
        'description' => __( 'Should Captcha be added to the customer order form to prevent spamming? Uses Google\'s reCAPTCHA system, so you will need to create a site key and secret for this feature to work.' , 'order-tracking' )
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-customer-order-form',
      'text',
      array(
        'id'            => 'captcha-site-key',
        'title'         => __( 'Google reCAPTCHA Site Key', 'order-tracking' ),
        'description'   => __( 'The site key provided to you by Google', 'order-tracking' ),
        'conditional_on'    => 'use-captcha',
        'conditional_on_value'  => true
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-customer-order-form',
      'text',
      array(
        'id'            => 'captcha-secret-key',
        'title'         => __( 'Google reCAPTCHA Secret Key', 'order-tracking' ),
        'description'   => __( 'The secret key provided to you by Google', 'order-tracking' ),
        'conditional_on'    => 'use-captcha',
        'conditional_on_value'  => true
      )
    );
  
    return $sap;
  }

  // "Locations" Tab
  public function ewd_otp_settings_locations_tab( $sap, $ewdotpSettings ) {

    $sap->add_section(
      'ewd-otp-settings',
      array_merge(
        array(
          'id'            => 'ewd-otp-locations',
          'title'         => __( 'Locations', 'order-tracking' ),
          'tab'         => 'ewd-otp-locations-tab',
        ),
        $this->get_permission( 'locations' )
      )
    );

    $locations_description = __( 'Locations help your customers to know where their order is.', 'order-tracking' ) . '<br />';
    
    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-locations',
      'infinite_table',
      array(
        'id'      => 'locations',
        'title'     => __( 'Locations', 'order-tracking' ),
        'add_label'   => __( '+ ADD', 'order-tracking' ),
        'del_label'   => __( 'Delete', 'order-tracking' ),
        'description' => $locations_description,
        'fields'    => array(
          'name' => array(
            'type'    => 'text',
            'label'   => 'Name',
            'required'  => true
          ),
          'latitude' => array(
            'type'    => 'text',
            'label'   => 'Latitude',
            'required'  => false
          ),
          'longitude' => array(
            'type'    => 'text',
            'label'   => 'Longitude',
            'required'  => false
          )
        )
      )
    );
  
    return $sap;
  }

  // "Notifications" Tab
  public function ewd_otp_settings_notifications_tab( $sap, $ewdotpSettings ) {

    $sap->add_section(
      'ewd-otp-settings',
      array_merge(
        array(
          'id'            => 'ewd-otp-sms-options',
          'title'         => __( 'SMS Options', 'order-tracking' ),
          'tab'         => 'ewd-otp-notifications-tab',
          'ultimate_needed' => true,
        ),
        $this->get_permission( 'sms' )
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-sms-options',
      'text',
      array(
        'id'      => 'ultimate-purchase-email',
        'title'     => __( 'Ultimate Plan Purchase Email', 'order-tracking' ),
        'description' => __( 'The email used to purchase your \'Ultimate\' plan subscription. Used to verify SMS requests are actually being sent from your site.', 'order-tracking' ),
        'placeholder' => isset( $ewdotpSettings->defaults['ultimate-purchase-email'] ) ? $ewdotpSettings->defaults['ultimate-purchase-email'] : '',
      )
    );

    $country_phone_array = isset( $ewdotpSettings->country_phone_array ) ? $ewdotpSettings->country_phone_array : array();

    $country_phone_display_array = array();

    foreach ( $country_phone_array as $country_code => $country_array ) {
      $country_phone_display_array[$country_code] = $country_array['name'] . ' (+' . $country_array['code'] . ')';
    }

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-sms-options',
      'select',
      array(
        'id'            => 'sms-country-code',
        'title'         => __( 'Country Code', 'order-tracking' ),
        'description'   => __( 'What country code should be added to SMS notifications? If no country is specified, phone numbers for orders should start with +XXX (a plus sign followed by the country code), followed by a space or dash, or else the phone number will be assumed to be North American.', 'order-tracking' ),
        'blank_option'  => true,
        'options'       => $country_phone_display_array
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-sms-options',
      'text',
      array(
        'id'            => 'admin-phone-number',
        'title'         => __( 'Admin Phone Number', 'order-tracking' ),
        'description' => __( 'What phone number should customer note and customer order notifications be sent to, if they\'ve been set to an SMS message in the "Premium" area of the "Settings" page?', 'order-tracking' ),
      )
    );

    $text_messages_description = __( 'What should be in the messages sent to users? You can put [order-name], [order-number], [order-status], [order-notes], [customer-notes] and [order-time] into the message, to include current order name, order number, order status, public order notes or the time the order was updated.', 'order-tracking' ) . '<br />';
    $text_messages_description .= __( 'You can also use [tracking-link], [customer-name], [customer-number], [customer-id], [sales-rep], [sales-rep-number] or the slug of a custom field enclosed in square brackets to include those fields in the message.', 'order-tracking' );
    
    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-sms-options',
      'infinite_table',
      array(
        'id'      => 'sms-messages',
        'title'     => __( 'SMS Messages', 'order-tracking' ),
        'add_label'   => __( '+ ADD', 'order-tracking' ),
        'del_label'   => __( 'Delete', 'order-tracking' ),
        'description' => $text_messages_description,
        'fields'    => array(
          'id' => array(
            'type'    => 'hidden',
            'label'   => 'ID',
            'required'  => true,
            'classes'   => array( 'sap-hidden' ),
          ),
          'name' => array(
            'type'    => 'text',
            'label'   => 'Name',
            'required'  => true
          ),
          'message' => array(
            'type'    => 'editor',
            'label'   => 'Message',
            'required'  => true
          )
        )
      )
    );

    return $sap;
  }

  // "Payments" Tab
  public function ewd_otp_settings_payments_tab( $sap, $ewdotpSettings ) {

    $sap->add_section(
      'ewd-otp-settings',
      array_merge(
        array(
          'id'            => 'ewd-otp-payment-options',
          'title'         => __( 'Payment Options', 'order-tracking' ),
          'tab'         => 'ewd-otp-payments-tab',
        ),
        $this->get_permission( 'payments' )
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-payment-options',
      'toggle',
      array(
        'id'      => 'allow-order-payments',
        'title'     => __( 'Allow Order Payment By PayPal', 'order-tracking' ),
        'description' => __( 'Should order payment be possible via PayPal?', 'order-tracking' )
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-payment-options',
      'select',
      array(
        'id'            => 'default-payment-status',
        'title'         => __( 'Default Post-Payment Status', 'order-tracking' ),
        'description'   => __( 'What status, if any, should an order be set to after payment is received?', 'order-tracking' ), 
        'blank_option'  => true,
        'options'       => $ewdotpSettings->status_options,
        'conditional_on'    => 'allow-order-payments',
        'conditional_on_value'  => true
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-payment-options',
      'text',
      array(
        'id'            => 'paypal-email-address',
        'title'         => __( 'PayPal Email Address', 'order-tracking' ),
        'description' => __( 'If PayPal payments are possible, what email address is associated with the PayPal account?', 'order-tracking' ),
        'small'     => true,
        'conditional_on'    => 'allow-order-payments',
        'conditional_on_value'  => true
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-payment-options',
      'select',
      array(
        'id'            => 'pricing-currency-code',
        'title'         => __( 'Pricing Currency', 'order-tracking' ),
        'description'   => __( 'What currency are your orders priced in?', 'order-tracking' ), 
        'blank_option'  => true,
        'options'       => $ewdotpSettings->currency_options,
        'conditional_on'    => 'allow-order-payments',
        'conditional_on_value'  => true
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-payment-options',
      'text',
      array(
        'id'            => 'thank-you-url',
        'title'         => __( '"Thank You" Page URL', 'order-tracking' ),
        'description' => __( 'What page should customers be taken to after successfully completing a PayPal payment?', 'order-tracking' ),
        'small'     => true,
        'conditional_on'    => 'allow-order-payments',
        'conditional_on_value'  => true
      )
    );
  
    return $sap;
  }

  // "WooCommerce" Tab
  public function ewd_otp_settings_woocommerce_tab( $sap, $ewdotpSettings ) {

    $sap->add_section(
      'ewd-otp-settings',
      array_merge(
        array(
          'id'            => 'ewd-otp-woocommerce-options',
          'title'         => __( 'WooCommerce Options', 'order-tracking' ),
          'tab'         => 'ewd-otp-woocommerce-tab',
        ),
        $this->get_permission( 'woocommerce' )
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-woocommerce-options',
      'toggle',
      array(
        'id'      => 'woocommerce-integration',
        'title'     => __( 'WooCommerce Integration', 'order-tracking' ),
        'description' => __( 'Should WooCommerce orders be automatically created inside of the Status Tracking plugin? (Only works for new orders)', 'order-tracking' )
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-woocommerce-options',
      'text',
      array(
        'id'            => 'woocommerce-prefix',
        'title'         => __( 'WooCommerce Prefix', 'order-tracking' ),
        'description' => __( 'What prefix, if any, should be added to WooCommerce order numbers?', 'order-tracking' ),
        'small'     => true,
        'conditional_on'    => 'woocommerce-integration',
        'conditional_on_value'  => true
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-woocommerce-options',
      'toggle',
      array(
        'id'      => 'woocommerce-disable-random-suffix',
        'title'     => __( 'Disable WooCommerce Random Suffix', 'order-tracking' ),
        'description' => __( 'Should the random characters added to WooCommerce orders be not be added?', 'order-tracking' ),
        'conditional_on'    => 'woocommerce-integration',
        'conditional_on_value'  => true
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-woocommerce-options',
      'toggle',
      array(
        'id'      => 'woocommerce-show-on-order-page',
        'title'     => __( 'Show Tracking On Order Page', 'order-tracking' ),
        'description' => __( 'Should order status information be displayed on the order page?', 'order-tracking' ),
        'conditional_on'    => 'woocommerce-integration',
        'conditional_on_value'  => true
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-woocommerce-options',
      'toggle',
      array(
        'id'      => 'woocommerce-locations-enabled',
        'title'     => __( 'Location Dropdown for WooCommerce Orders', 'order-tracking' ),
        'description' => __( 'Should a location dropdown be added to the WooCommerce "Edit Order" screen?', 'order-tracking' ),
        'conditional_on'    => 'woocommerce-integration',
        'conditional_on_value'  => true
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-woocommerce-options',
      'toggle',
      array(
        'id'      => 'woocommerce-replace-statuses',
        'title'     => __( 'Replace WooCommerce Statuses with Status Tracking Statuses', 'order-tracking' ),
        'description' => __( 'Should order tracking statuses replace the default WooCommerce statuses?', 'order-tracking' ),
        'conditional_on'    => 'woocommerce-integration',
        'conditional_on_value'  => true
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-woocommerce-options',
      'toggle',
      array(
        'id'      => 'disable-woocommerce-revert-statuses',
        'title'     => __( 'Disable Revert WooCommerce Statuses on Deactivation', 'order-tracking' ),
        'description' => __( 'Should WooCommerce orders having their statuses returned to one of the defaults when the plugin is deactivated be disabled? This is disabled by default if WooCommerce integration is not enabled, but could result in orders with custom statuses being hidden from the WooCommerce admin orders table after deactivation.', 'order-tracking' ),
        'conditional_on'    => 'woocommerce-integration',
        'conditional_on_value'  => true
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-woocommerce-options',
      'select',
      array(
        'id'            => 'woocommerce-paid-status',
        'title'         => __( 'WooCommerce Completed Order Status', 'order-tracking' ),
        'description'   => __( 'What status should an order be set to when it\'s paid for successfully?', 'order-tracking' ), 
        'blank_option'  => true,
        'options'       => $ewdotpSettings->status_options,
        'conditional_on'    => 'woocommerce-integration',
        'conditional_on_value'  => true
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-woocommerce-options',
      'select',
      array(
        'id'            => 'woocommerce-unpaid-status',
        'title'         => __( 'WooCommerce Unpaid Order Status', 'order-tracking' ),
        'description'   => __( 'What status should an order be set to when it\'s unpaid?', 'order-tracking' ), 
        'blank_option'  => true,
        'options'       => $ewdotpSettings->status_options,
        'conditional_on'    => 'woocommerce-integration',
        'conditional_on_value'  => true
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-woocommerce-options',
      'select',
      array(
        'id'            => 'woocommerce-processing-status',
        'title'         => __( 'WooCommerce Processing Order Status', 'order-tracking' ),
        'description'   => __( 'What status should an order be set to when it\'s processing?', 'order-tracking' ), 
        'blank_option'  => true,
        'options'       => $ewdotpSettings->status_options,
        'conditional_on'    => 'woocommerce-integration',
        'conditional_on_value'  => true
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-woocommerce-options',
      'select',
      array(
        'id'            => 'woocommerce-cancelled-status',
        'title'         => __( 'WooCommerce Cancelled Order Status', 'order-tracking' ),
        'description'   => __( 'What status should an order be set to when it\'s cancelled?', 'order-tracking' ), 
        'blank_option'  => true,
        'options'       => $ewdotpSettings->status_options,
        'conditional_on'    => 'woocommerce-integration',
        'conditional_on_value'  => true
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-woocommerce-options',
      'select',
      array(
        'id'            => 'woocommerce-onhold-status',
        'title'         => __( 'WooCommerce On-Hold Order Status', 'order-tracking' ),
        'description'   => __( 'What status should an order be set to when it\'s on-hold?', 'order-tracking' ), 
        'blank_option'  => true,
        'options'       => $ewdotpSettings->status_options,
        'conditional_on'    => 'woocommerce-integration',
        'conditional_on_value'  => true
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-woocommerce-options',
      'select',
      array(
        'id'            => 'woocommerce-failed-status',
        'title'         => __( 'WooCommerce Failed Order Status', 'order-tracking' ),
        'description'   => __( 'What status should an order be set to when it fails?', 'order-tracking' ), 
        'blank_option'  => true,
        'options'       => $ewdotpSettings->status_options,
        'conditional_on'    => 'woocommerce-integration',
        'conditional_on_value'  => true
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-woocommerce-options',
      'select',
      array(
        'id'            => 'woocommerce-refunded-status',
        'title'         => __( 'WooCommerce Refunded Order Status', 'order-tracking' ),
        'description'   => __( 'What status should an order be set to when it\'s refunded?', 'order-tracking' ), 
        'blank_option'  => true,
        'options'       => $ewdotpSettings->status_options,
        'conditional_on'    => 'woocommerce-integration',
        'conditional_on_value'  => true
      )
    );
  
    return $sap;
  }

  // "Zendesk" Tab
  public function ewd_otp_settings_zendesk_tab( $sap, $ewdotpSettings ) {
    
    $sap->add_section(
      'ewd-otp-settings',
      array_merge(
        array(
          'id'            => 'ewd-otp-zendesk-options',
          'title'         => __( 'Zendesk Options', 'order-tracking' ),
          'tab'         => 'ewd-otp-zendesk-tab',
        ),
        $this->get_permission( 'zendesk' )
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-zendesk-options',
      'toggle',
      array(
        'id'      => 'zendesk-integration',
        'title'     => __( 'Zendesk Integration', 'order-tracking' ),
        'description' => __( 'Should the plugin listen for new tickets from Zendesk?<br>Check out our <a style=\'display:inline; padding-left:0px;\' href=\'http://www.etoilewebdesign.com/status-tracking-zendesk-integration/\'>tutorial on setting up Status Tracking-Zendesk integration</a>', 'order-tracking' )
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-zendesk-options',
      'text',
      array(
        'id'            => 'zendesk-api-key',
        'title'         => __( 'Zendesk API Key (optional)', 'order-tracking' ),
        'description' => __( 'The (optional) key you\'re using to make sure that fake tickets can\'t be created by a 3rd party.', 'order-tracking' ),
        'small'     => true,
        'conditional_on'    => 'zendesk-integration',
        'conditional_on_value'  => true
      )
    );

    return $sap;
  }

  // "Labelling" Tab
  public function ewd_otp_settings_labelling_tab( $sap, $ewdotpSettings ) {
    
    $sap->add_section(
      'ewd-otp-settings',
      array_merge(
        array(
          'id'            => 'ewd-otp-labelling-tracking-form',
          'title'         => __( 'Tracking Form', 'order-tracking' ),
          'tab'         => 'ewd-otp-labelling-tab',
        ),
        $this->get_permission( 'labelling' )
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-labelling-tracking-form',
      'text',
      array(
        'id'            => 'label-order-form-title',
        'title'         => __( 'Tracking Form Title', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-labelling-tracking-form',
      'text',
      array(
        'id'            => 'label-order-form-number',
        'title'         => __( 'Order Number Label', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-labelling-tracking-form',
      'text',
      array(
        'id'            => 'label-order-form-number-placeholder',
        'title'         => __( 'Order Number Placeholder', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-labelling-tracking-form',
      'text',
      array(
        'id'            => 'label-order-form-email',
        'title'         => __( 'Email Address', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-labelling-tracking-form',
      'text',
      array(
        'id'            => 'label-order-form-email-placeholder',
        'title'         => __( 'Email Address Placeholder', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-labelling-tracking-form',
      'text',
      array(
        'id'            => 'label-order-form-button',
        'title'         => __( 'Track button', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-labelling-tracking-form',
      'text',
      array(
        'id'            => 'label-retrieving-results',
        'title'         => __( 'Retrieving Results', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_section(
      'ewd-otp-settings',
      array_merge(
        array(
          'id'            => 'ewd-otp-labelling-customer-form',
          'title'         => __( 'Customer Form', 'order-tracking' ),
          'tab'         => 'ewd-otp-labelling-tab',
        ),
        $this->get_permission( 'labelling' )
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-labelling-customer-form',
      'text',
      array(
        'id'            => 'label-customer-form-title',
        'title'         => __( 'Form Title', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-labelling-customer-form',
      'text',
      array(
        'id'            => 'label-customer-form-instructions',
        'title'         => __( 'Instructions', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-labelling-customer-form',
      'text',
      array(
        'id'            => 'label-customer-form-number',
        'title'         => __( 'Customer Number Label', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-labelling-customer-form',
      'text',
      array(
        'id'            => 'label-customer-form-number-placeholder',
        'title'         => __( 'Customer Number Placeholder', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-labelling-customer-form',
      'text',
      array(
        'id'            => 'label-customer-form-email',
        'title'         => __( 'Email Address', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-labelling-customer-form',
      'text',
      array(
        'id'            => 'label-customer-form-email-placeholder',
        'title'         => __( 'Email Address Placeholder', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-labelling-customer-form',
      'text',
      array(
        'id'            => 'label-customer-form-button',
        'title'         => __( 'Track button', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_section(
      'ewd-otp-settings',
      array_merge(
        array(
          'id'            => 'ewd-otp-labelling-sales-rep-form',
          'title'         => __( 'Sales Rep Form', 'order-tracking' ),
          'tab'         => 'ewd-otp-labelling-tab',
        ),
        $this->get_permission( 'labelling' )
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-labelling-sales-rep-form',
      'text',
      array(
        'id'            => 'label-sales-rep-form-title',
        'title'         => __( 'Form Title', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-labelling-sales-rep-form',
      'text',
      array(
        'id'            => 'label-sales-rep-form-instructions',
        'title'         => __( 'Instructions', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-labelling-sales-rep-form',
      'text',
      array(
        'id'            => 'label-sales-rep-form-number',
        'title'         => __( 'Sales Rep Number Label', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-labelling-sales-rep-form',
      'text',
      array(
        'id'            => 'label-sales-rep-form-number-placeholder',
        'title'         => __( 'Sales Rep Number Placeholder', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-labelling-sales-rep-form',
      'text',
      array(
        'id'            => 'label-sales-rep-form-email',
        'title'         => __( 'Email Address', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-labelling-sales-rep-form',
      'text',
      array(
        'id'            => 'label-sales-rep-form-email-placeholder',
        'title'         => __( 'Email Address Placeholder', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-labelling-sales-rep-form',
      'text',
      array(
        'id'            => 'label-sales-rep-form-button',
        'title'         => __( 'Track button', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_section(
      'ewd-otp-settings',
      array_merge(
        array(
          'id'            => 'ewd-otp-labelling-order-display',
          'title'         => __( 'Order Display Page', 'order-tracking' ),
          'tab'         => 'ewd-otp-labelling-tab',
        ),
        $this->get_permission( 'labelling' )
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-labelling-order-display',
      'text',
      array(
        'id'            => 'label-order-information',
        'title'         => __( 'Order Information', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-labelling-order-display',
      'text',
      array(
        'id'            => 'label-order-number',
        'title'         => __( 'Order Number', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-labelling-order-display',
      'text',
      array(
        'id'            => 'label-order-name',
        'title'         => __( 'Order Name', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-labelling-order-display',
      'text',
      array(
        'id'            => 'label-order-notes',
        'title'         => __( 'Order Notes', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-labelling-order-display',
      'text',
      array(
        'id'            => 'label-customer-notes',
        'title'         => __( 'Customer Notes', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-labelling-order-display',
      'text',
      array(
        'id'            => 'label-order-status',
        'title'         => __( 'Order Status', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-labelling-order-display',
      'text',
      array(
        'id'            => 'label-order-location',
        'title'         => __( 'Order Location', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-labelling-order-display',
      'text',
      array(
        'id'            => 'label-order-updated',
        'title'         => __( 'Order Updated', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-labelling-order-display',
      'text',
      array(
        'id'            => 'label-order-current-location',
        'title'         => __( 'Current Location', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-labelling-order-display',
      'text',
      array(
        'id'            => 'label-order-print-button',
        'title'         => __( 'Print Button', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-labelling-order-display',
      'text',
      array(
        'id'            => 'label-order-add-note-button',
        'title'         => __( 'Add Note Button', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-labelling-order-display',
      'text',
      array(
        'id'            => 'label-order-update-status',
        'title'         => __( 'Update Status Button', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_section(
      'ewd-otp-settings',
      array_merge(
        array(
          'id'            => 'ewd-otp-labelling-customer-form-display',
          'title'         => __( 'Customer Form Display Page', 'order-tracking' ),
          'tab'         => 'ewd-otp-labelling-tab',
        ),
        $this->get_permission( 'labelling' )
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-labelling-customer-form-display',
      'text',
      array(
        'id'            => 'label-customer-display-number',
        'title'         => __( 'Customer Number', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-labelling-customer-form-display',
      'text',
      array(
        'id'            => 'label-customer-display-name',
        'title'         => __( 'Customer Name', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-labelling-customer-form-display',
      'text',
      array(
        'id'            => 'label-customer-display-email',
        'title'         => __( 'Customer Email', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-labelling-customer-form-display',
      'text',
      array(
        'id'            => 'label-customer-display-download',
        'title'         => __( 'Download All Orders', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_section(
      'ewd-otp-settings',
      array_merge(
        array(
          'id'            => 'ewd-otp-labelling-sales-rep-form-display',
          'title'         => __( 'Sales Rep Form Display Page', 'order-tracking' ),
          'tab'         => 'ewd-otp-labelling-tab',
        ),
        $this->get_permission( 'labelling' )
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-labelling-sales-rep-form-display',
      'text',
      array(
        'id'            => 'label-sales-rep-display-number',
        'title'         => __( 'Sales Rep Number', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-labelling-sales-rep-form-display',
      'text',
      array(
        'id'            => 'label-sales-rep-display-first-name',
        'title'         => __( 'Sales Rep First Name', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-labelling-sales-rep-form-display',
      'text',
      array(
        'id'            => 'label-sales-rep-display-last-name',
        'title'         => __( 'Sales Rep Last Name', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-labelling-sales-rep-form-display',
      'text',
      array(
        'id'            => 'label-sales-rep-display-email',
        'title'         => __( 'Sales Rep Email', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-labelling-sales-rep-form-display',
      'text',
      array(
        'id'            => 'label-sales-rep-display-download',
        'title'         => __( 'Download All Orders', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_section(
      'ewd-otp-settings',
      array_merge(
        array(
          'id'            => 'ewd-otp-labelling-customer-order-form-display',
          'title'         => __( 'Customer Order Form', 'order-tracking' ),
          'tab'         => 'ewd-otp-labelling-tab',
        ),
        $this->get_permission( 'labelling' )
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-labelling-customer-order-form-display',
      'text',
      array(
        'id'            => 'label-customer-order-name',
        'title'         => __( 'Order Name', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-labelling-customer-order-form-display',
      'text',
      array(
        'id'            => 'label-customer-order-email',
        'title'         => __( 'Order Email Address', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-labelling-customer-order-form-display',
      'text',
      array(
        'id'            => 'label-customer-order-email-instructions',
        'title'         => __( 'Email Instructions', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-labelling-customer-order-form-display',
      'text',
      array(
        'id'            => 'label-customer-order-phone',
        'title'         => __( 'Order Phone Number', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-labelling-customer-order-form-display',
      'text',
      array(
        'id'            => 'label-customer-order-phone-instructions',
        'title'         => __( 'Phone Number Instructions', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-labelling-customer-order-form-display',
      'text',
      array(
        'id'            => 'label-customer-order-notes',
        'title'         => __( 'Customer Notes', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-labelling-customer-order-form-display',
      'text',
      array(
        'id'            => 'label-customer-order-button',
        'title'         => __( 'Send Order button', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-labelling-customer-order-form-display',
      'text',
      array(
        'id'            => 'label-customer-order-thank-you',
        'title'         => __( 'Thank You Message', 'order-tracking' ),
        'description' => ''
      )
    );

    return $sap;
  }

  // "Styling" Tab
  public function ewd_otp_settings_styling_tab( $sap, $ewdotpSettings ) {
    
    $sap->add_section(
      'ewd-otp-settings',
      array_merge(
        array(
          'id'            => 'ewd-otp-styling',
          'title'         => __( 'Styling Options', 'order-tracking' ),
          'tab'         => 'ewd-otp-styling-tab',
        ),
        $this->get_permission( 'styling' )
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-styling',
      'text',
      array(
        'id'            => 'styling-title-font',
        'title'         => __( 'Title Font Family', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-styling',
      'text',
      array(
        'id'            => 'styling-title-font-size',
        'title'         => __( 'Title Font Size', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-styling',
      'colorpicker',
      array(
        'id'      => 'styling-title-font-color',
        'title'     => __( 'Title Font Color', 'order-tracking' )
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-styling',
      'text',
      array(
        'id'            => 'styling-title-margin',
        'title'         => __( 'Title Margin', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-styling',
      'text',
      array(
        'id'            => 'styling-title-padding',
        'title'         => __( 'Title Padding', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-styling',
      'text',
      array(
        'id'            => 'styling-label-font',
        'title'         => __( 'Label Font Family', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-styling',
      'text',
      array(
        'id'            => 'styling-label-font-size',
        'title'         => __( 'Label Font Size', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-styling',
      'colorpicker',
      array(
        'id'      => 'styling-label-font-color',
        'title'     => __( 'Label Font Color', 'order-tracking' )
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-styling',
      'text',
      array(
        'id'            => 'styling-label-margin',
        'title'         => __( 'Label Margin', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-styling',
      'text',
      array(
        'id'            => 'styling-label-padding',
        'title'         => __( 'Label Padding', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-styling',
      'text',
      array(
        'id'            => 'styling-content-font',
        'title'         => __( 'Content Font Family', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-styling',
      'text',
      array(
        'id'            => 'styling-content-font-size',
        'title'         => __( 'Content Font Size', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-styling',
      'colorpicker',
      array(
        'id'      => 'styling-content-font-color',
        'title'     => __( 'Content Font Color', 'order-tracking' )
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-styling',
      'text',
      array(
        'id'            => 'styling-content-margin',
        'title'         => __( 'Content Margin', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-styling',
      'text',
      array(
        'id'            => 'styling-content-padding',
        'title'         => __( 'Content Padding', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-styling',
      'colorpicker',
      array(
        'id'      => 'styling-button-font-color',
        'title'     => __( 'Button Font Color', 'order-tracking' )
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-styling',
      'colorpicker',
      array(
        'id'      => 'styling-button-background-color',
        'title'     => __( 'Button Background Color', 'order-tracking' )
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-styling',
      'text',
      array(
        'id'            => 'styling-button-border',
        'title'         => __( 'Button Border', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-styling',
      'text',
      array(
        'id'            => 'styling-button-margin',
        'title'         => __( 'Button Margin', 'order-tracking' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-otp-settings',
      'ewd-otp-styling',
      'text',
      array(
        'id'            => 'styling-button-padding',
        'title'         => __( 'Button Padding', 'order-tracking' ),
        'description' => ''
      )
    );

    return $sap;
  }

  /**
   * Adds the SMS notifications to the notification options array
   * @since 0.25
   */
  public function add_sms_message_options_to_notifications( $notifications, $ewdotpSettings ) {
    global $ewd_otp_controller;

    if ( empty( $ewd_otp_controller->permissions->check_permission( 'sms' ) ) ) { return $notifications; }

    $sms_messages = ewd_otp_decode_infinite_table_setting( $ewd_otp_controller->settings->get_setting( 'sms-messages' ) );

    $sms_notifications = array();

    foreach ( $sms_messages as $sms_message ) { 

      $sms_notifications[ 'sms_' . $sms_message->id ] = $sms_message->name;
    }

    $notifications['SMS Messages'] = $sms_notifications;

    return $notifications;
  }

}
}