<?php
if ( ! defined( 'ABSPATH' ) ) exit;

if ( !class_exists( 'ewdurpEWDPHSettings' ) ) {
class ewdurpEWDPHSettings {

  public function __construct() {

    add_filter( 'ewd_urp_defaults', array( $this, 'ewd_urp_settings_set_defaults' ), 10, 2 );

    add_filter( 'ewd_urp_settings_page', array( $this, 'ewd_urp_settings__non_premium_tabs' ), 10, 2 );

    add_filter( 'ewd_urp_settings_page', array( $this, 'ewd_urp_settings_premium_tab' ), 10, 2 );
    add_filter( 'ewd_urp_settings_page', array( $this, 'ewd_urp_settings_woocommerce_tab' ), 10, 2 );
    add_filter( 'ewd_urp_settings_page', array( $this, 'ewd_urp_settings_labelling_tab' ), 10, 2 );
    add_filter( 'ewd_urp_settings_page', array( $this, 'ewd_urp_settings_styling_tab' ), 10, 2 );
  }

  public function get_permission( $permission_type = '' ) {
    global $ewd_urp_controller;
  
    $ewd_urp_premium_permissions = array();
  
    if ( ! $ewd_urp_controller->permissions->check_permission( $permission_type ) ) {
      $ewd_urp_premium_permissions = array(
        'disabled'    => true,
        'disabled_image'=> '#',
        'purchase_link' => 'https://www.etoilewebdesign.com/plugins/ultimate-reviews/?utm_source=urp_lockbox'
      );
    }
  
    return $ewd_urp_premium_permissions;
  }

  public function ewd_urp_settings_set_defaults( $defaults, $ewdurpSettings ) {

    $defaults = array_merge(
      $defaults,
      array(
        // Any default which you are certain that won't be used for free version.
      )
    );
  
    return $defaults;
  }

  public function ewd_urp_settings__non_premium_tabs( $sap, $ewdurpSettings ) {

    return $sap;
  }

  // "Premium" Tab
  public function ewd_urp_settings_premium_tab( $sap, $ewdurpSettings ) {
    
    $sap->add_section(
      'ewd-urp-settings',
      array_merge(
        array(
        'id'            => 'ewd-urp-premium-general',
        'title'         => __( 'General', 'ultimate-reviews' ),
        'tab'         => 'ewd-urp-premium-tab',
        ),
        $this->get_permission( 'premium' )
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-premium-general',
      'radio',
      array(
        'id'      => 'review-format',
        'title'     => __( 'Review Format', 'ultimate-reviews' ),
        'description' => '',
        'default'   => $ewdurpSettings->defaults['review-format'],
        'options'   => array(
          'standard'      => __( 'Standard', 'ultimate-reviews' ),
          'expandable'    => __( 'Expandable', 'ultimate-reviews' ),
          'thumbnail'     => __( 'Thumbnail', 'ultimate-reviews' ),
          'thumbnail_masonry' => __( 'Thumbnail Masonry', 'ultimate-reviews' ),
          'image'       => __( 'Image', 'ultimate-reviews' ),
          'image_masonry'   => __( 'Image Masonry', 'ultimate-reviews' ),
        )
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-premium-general',
      'toggle',
      array(
        'id'      => 'use-captcha',
        'title'     => __( 'Captcha', 'ultimate-reviews' ),
        'description' => __( 'Should Captcha be added to the submit review form to prevent spamming? (requires image-creation support for your PHP installation)', 'ultimate-reviews' )
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-premium-general',
      'radio',
      array(
        'id'      => 'captcha-type',
        'title'     => __( 'Captcha Type', 'ultimate-reviews' ),
        'description' => sprintf( __( 'Plain text will soon be deprecated as it is easier to bypass. Google\'s reCAPTCHA code to your form, to verify guests before they can book. Please check %s our documentation %s for more information on how to configure this feature.', 'ultimate-reviews' ), '<a href="https://www.etoilewebdesign.com/2021/09/02/setting-up-recatpcha-in-the-ultimate-reviews-plugin/" target="_blank">', '</a>'),
        'default'   => $ewdurpSettings->defaults['captcha-type'],
        'options'   => array(
          'text'      => __( 'Plain Text', 'ultimate-reviews' ),
          'recaptcha'   => __( 'Google ReCAPTCHA', 'ultimate-reviews' ),
        ),
        'conditional_on'    => 'use-captcha',
        'conditional_on_value'  => true
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-premium-general',
      'text',
      array(
        'id'            => 'captcha-site-key',
        'title'         => __( 'Google Site Key', 'ultimate-reviews' ),
        'description'   => __( 'The site key provided to you by Google', 'ultimate-reviews' ),
        'conditional_on'    => 'captcha-type',
        'conditional_on_value'  => 'recaptcha'
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-premium-general',
      'text',
      array(
        'id'            => 'captcha-secret-key',
        'title'         => __( 'Google Secret Key', 'ultimate-reviews' ),
        'description'   => __( 'The secret key provided to you by Google', 'ultimate-reviews' ),
        'conditional_on'    => 'captcha-type',
        'conditional_on_value'  => 'recaptcha'
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-premium-general',
      'toggle',
      array(
        'id'      => 'review-karma',
        'title'     => __( 'Review Karma', 'ultimate-reviews' ),
        'description' => __( 'Should visitors be allowed to vote up or down reviews that they find or don\'t find useful? ("Did you find this review helpful?") Uses cookies to make it more difficult to vote up or down multiple times.', 'ultimate-reviews' )
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-premium-general',
      'toggle',
      array(
        'id'      => 'infinite-scroll',
        'title'     => __( 'Infinite Scroll', 'ultimate-reviews' ),
        'description' => __( 'If there are more than the maximum number of reviews per page displayed, should the next page of reviews be loaded automatically by AJAX so that the page doesn\'t need to be reloaded? This may not work if you also have a review widget displaying on the same page.', 'ultimate-reviews' )
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-premium-general',
      'toggle',
      array(
        'id'      => 'display-microdata',
        'title'     => __( 'Include Microdata', 'ultimate-reviews' ),
        'description' => __( 'Should microdata be added to the reviews when they\'re displayed? Microdata helps search engine to display your reviews in a more helpful format <a href="http://www.htmlgoodies.com/html5/Web-Developer-Tutorial-HTML5-Microdata-3920016.htm#fbid=UWk0EObAqCE">Find out more</a>).', 'ultimate-reviews' )
      )
    );

    $microdata_types = array(
      'Book'          => 'Book',
      'Course'        => 'Course',
      'CreativeWorkSeason'  => 'Creative Work - Season',
      'CreativeWorkSeries'  => 'Creative Work - Series',
      'Episode'         => 'Episode',
      'Event'         => 'Event',
      'Game'          => 'Game',
      'HowTo'         => 'How To',
      'LocalBusiness'     => 'Local Business',
      'MediaObject'       => 'Media Object',
      'Movie'         => 'Movie',
      'MusicPlaylist'     => 'Music Playlist',
      'MusicRecording'    => 'Music Recording',
      'Organization'      => 'Organization',
      'Product'         => 'Product',
      'Recipe'        => 'Recipe',
      'SoftwareApplication'   => 'Software Application'
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-premium-general',
      'select',
      array(
        'id'            => 'items-reviewed',
        'title'         => __( 'Items Reviewed', 'ultimate-reviews' ),
        'description'   => __( 'For microdata to work correctly, the type of items being reviewed needs to be specified.', 'ultimate-reviews' ),
        'default'   => $ewdurpSettings->defaults['items-reviewed'],
        'blank_option'  => false,
        'options'       => $microdata_types
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-premium-general',
      'toggle',
      array(
        'id'      => 'admin-notification',
        'title'     => __( 'Admin Notification Email', 'ultimate-reviews' ),
        'description' => __( 'Should an email be sent to the WordPress admin?', 'ultimate-reviews' )
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-premium-general',
      'text',
      array(
        'id'            => 'admin-email-address',
        'title'         => __( 'Admin Email Address', 'ultimate-reviews' ),
        'description' => __( 'The email address admin notifications should be sent to, if "Admin Notification Email" is enabled. Leave blank to use the default WordPress admin email.', 'ultimate-reviews' ),
        'conditional_on'    => 'admin-notification',
        'conditional_on_value'  => true
      )
    );

    $sap->add_section(
      'ewd-urp-settings',
      array_merge(
        array(
          'id'            => 'ewd-urp-premium-display',
          'title'         => __( 'Display Features', 'ultimate-reviews' ),
          'tab'         => 'ewd-urp-premium-tab',
        ),
        $this->get_permission( 'premium' )
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-premium-display',
      'radio',
      array(
        'id'      => 'summary-statistics',
        'title'     => __( 'Summary Statistics', 'ultimate-reviews' ),
        'description' => __( 'Should a summary of the reviews be displayed at the top (average score, etc.)? This feature may not work as expected with in-depth reviews and/or pagination.', 'ultimate-reviews' ),
        'default'   => $ewdurpSettings->defaults['summary-statistics'],
        'options'   => array(
          'full'      => __( 'Full', 'ultimate-reviews' ),
          'limited'   => __( 'Limited', 'ultimate-reviews' ),
          'none'      => __( 'None', 'ultimate-reviews' ),
        )
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-premium-display',
      'toggle',
      array(
        'id'      => 'summary-clickable',
        'title'     => __( 'Clickable Summary Stats', 'ultimate-reviews' ),
        'description' => __( 'Should visitors be able to click on the summary statistic bars to view all reviews with that score?', 'ultimate-reviews' ),
        'conditional_on'    => 'summary-statistics',
        'conditional_on_value'  => 'full'
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-premium-display',
      'text',
      array(
        'id'            => 'thumbnail-characters',
        'title'         => __( 'Thumbnail Characters', 'ultimate-reviews' ),
        'description' => __( 'What is the maximum number of characters that should be shown in the preview in thumbnail format?', 'ultimate-reviews' ),
        'small'     => true,
        'placeholder' => $ewdurpSettings->defaults['thumbnail-characters']
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-premium-display',
      'toggle',
      array(
        'id'      => 'read-more-ajax',
        'title'     => __( 'Thumbnail \'Read More\' AJAX', 'ultimate-reviews' ),
        'description' => __( 'If you have selected the "Thumbnail" format, should the content be loaded on the same page when clicking "Read More"?', 'ultimate-reviews' )
      )
    );

    $sap->add_section(
      'ewd-urp-settings',
      array_merge(
        array(
          'id'            => 'ewd-urp-premium-restrictions',
          'title'         => __( 'Restrictions', 'ultimate-reviews' ),
          'tab'         => 'ewd-urp-premium-tab',
        ),
        $this->get_permission( 'premium' )
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-premium-restrictions',
      'toggle',
      array(
        'id'      => 'admin-approval',
        'title'     => __( 'Require Admin Approval', 'ultimate-reviews' ),
        'description' => __( 'Should new reviews have their status set to \'draft\' until an admin decides to publish them?', 'ultimate-reviews' )
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-premium-restrictions',
      'toggle',
      array(
        'id'      => 'require-email',
        'title'     => __( 'Require Author Email', 'ultimate-reviews' ),
        'description' => __( 'Do reviewers have to include their email address (not publicly displayed) when they post a review?', 'ultimate-reviews' )
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-premium-restrictions',
      'toggle',
      array(
        'id'      => 'email-confirmation',
        'title'     => __( 'Require Email Confirmation', 'ultimate-reviews' ),
        'description' => __( 'Do reviewers have to confirm their email address before their review is displayed?', 'ultimate-reviews' ),
        'conditional_on'    => 'require-email',
        'conditional_on_value'  => true
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-premium-restrictions',
      'toggle',
      array(
        'id'      => 'display-on-confirmation',
        'title'     => __( 'Display Form on Confirmation', 'ultimate-reviews' ),
        'description' => __( 'Should the submit review form be displayed when someone is confirming their email address?', 'ultimate-reviews' )
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-premium-restrictions',
      'toggle',
      array(
        'id'      => 'one-review-per-product-person',
        'title'     => __( 'One Review per Person/Product', 'ultimate-reviews' ),
        'description' => __( 'Should users be restricted to leaving one review per product? Uses cookies to track which products a user has reviewed.', 'ultimate-reviews' )
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-premium-restrictions',
      'textarea',
      array(
        'id'      => 'review-blacklist',
        'title'     => __( 'Review Blacklist', 'ultimate-reviews' ),
        'description' => __( 'Enter terms, one per line, that you should block reviews from being submitted. This can include IP addresses that you want to block, review titles, author names, email addresses, etc.', 'ultimate-reviews' ),     )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-premium-restrictions',
      'toggle',
      array(
        'id'      => 'require-login',
        'title'     => __( 'Require Login', 'ultimate-reviews' ),
        'description' => __( 'Do reviewers have to log in before they can post a review?', 'ultimate-reviews' )
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-premium-restrictions',
      'text',
      array(
        'id'            => 'wordpress-login-url',
        'title'         => __( 'WordPress Login URL', 'ultimate-reviews' ),
        'description' => __( 'The URL of your WordPress login page.', 'ultimate-reviews' ),
        'conditional_on'    => 'require-login',
        'conditional_on_value'  => true
      )
    );      
  
    return $sap;
  }

  // "WooCommerce" Tab
  public function ewd_urp_settings_woocommerce_tab( $sap, $ewdurpSettings ) {
    
    $sap->add_section(
      'ewd-urp-settings',
      array_merge(
        array(
          'id'            => 'ewd-urp-woocommerce-general',
          'title'         => __( 'WooCommerce Settings', 'ultimate-reviews' ),
          'tab'         => 'ewd-urp-woocommerce-tab',
        ),
        $this->get_permission( 'woocommerce' )
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-woocommerce-general',
      'toggle',
      array(
        'id'      => 'replace-woocommerce-reviews',
        'title'     => __( 'Replace WooCommerce Reviews', 'ultimate-reviews' ),
        'description' => __( 'Should the "Reviews" tab on the WooCommerce product page use Ultimate Reviews instead of the default WooCommerce system?', 'ultimate-reviews' )
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-woocommerce-general',
      'toggle',
      array(
        'id'      => 'woocommerce-review-submit-first',
        'title'     => __( 'Submit Review on Top', 'ultimate-reviews' ),
        'description' => __( 'Should the "Submit Review" form be displayed above a product\'s reviews in WooCommerce?', 'ultimate-reviews' ),
        'conditional_on'    => 'replace-woocommerce-reviews',
        'conditional_on_value'  => true
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-woocommerce-general',
      'toggle',
      array(
        'id'      => 'only-woocommerce-products',
        'title'     => __( 'Only Review WooCommerce Products', 'ultimate-reviews' ),
        'description' => __( 'Should visitors only be able to leave reviews for WooCommerce products, and no other products? Set "Product Name Input Type" in the "Basic" tab to "Dropdown" for this to work correctly', 'ultimate-reviews' ),
        'conditional_on'    => 'replace-woocommerce-reviews',
        'conditional_on_value'  => true
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-woocommerce-general',
      'radio',
      array(
        'id'            => 'woocommerce-review-types',
        'title'         => __( 'WooCommerce Review Types', 'ultimate-reviews' ),
        'description'   => __( 'How should WooCommerce reviews be organized?', 'ultimate-reviews' ),
        'default'   => $ewdurpSettings->defaults['woocommerce-review-types'],
        'options'       => array(
          'default'   => __( 'Default', 'ultimate-reviews' ),
          'date'      => __( 'Most recent reviews', 'ultimate-reviews' ),
          'rating'    => __( 'Top reviews', 'ultimate-reviews' ),
          'karma'     => __( 'Most voted reviews ("Review Karma" in "Premium" options must be set to "Yes")', 'ultimate-reviews' ),
        ),
        'conditional_on'    => 'replace-woocommerce-reviews',
        'conditional_on_value'  => true
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-woocommerce-general',
      'toggle',
      array(
        'id'      => 'override-woocommerce-ratings-display',
        'title'     => __( 'Override Product Page Ratings', 'ultimate-reviews' ),
        'description' => __( 'Should the ratings area under the product name on the WooCommerce product page use the ratings from our plugin, instead of those from the default WooCommerce reviews?', 'ultimate-reviews' ),
        'conditional_on'    => 'replace-woocommerce-reviews',
        'conditional_on_value'  => true
      )
    );

    // $sap->add_setting(
    //  'ewd-urp-settings',
    //  'ewd-urp-woocommerce-general',
    //  'toggle',
    //  array(
    //    'id'      => 'verified-buyer-badge',
    //    'title'     => __( 'Verified Buyer Badge', 'ultimate-reviews' ),
    //    'description' => __( 'Enable to display a "Verified Buyer" badge on reviews. (Requires that "Verified Buyers Only" be enabled.)', 'ultimate-reviews' )
    //  )
    // );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-woocommerce-general',
      'toggle',
      array(
        'id'      => 'match-woocommerce-categories',
        'title'     => __( 'Match WooCommerce Categories', 'ultimate-reviews' ),
        'description' => __( 'Should review categories match the product categories in WooCommerce, and automatically attach a product\'s categories to reviews of that product? This will override the category selected by the review author if enabled.', 'ultimate-reviews' ),
        'conditional_on'    => 'replace-woocommerce-reviews',
        'conditional_on_value'  => true
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-woocommerce-general',
      'text',
      array(
        'id'            => 'woocommerce-category-product-reviews',
        'title'         => __( 'Display Related Reviews', 'ultimate-reviews' ),
        'description' => __( 'Display reviews for other products in the same category (or categories) if there are less than the number of reviews above. Use 0 to never display reviews for other products.', 'ultimate-reviews' ),
        'small'     => true,
        'placeholder' => $ewdurpSettings->defaults['display-related-reviews'],
        'conditional_on'    => 'replace-woocommerce-reviews',
        'conditional_on_value'  => true
      )
    );

    $sap->add_section(
      'ewd-urp-settings',
      array_merge(
        array(
          'id'            => 'ewd-urp-woocommerce-review-reminders',
          'title'         => __( 'Review Reminder Emails', 'ultimate-reviews' ),
          'tab'         => 'ewd-urp-woocommerce-tab',
        ),
        $this->get_permission( 'woocommerce' )
      )
    );

    $review_reminders_description = '<ul><li>';
    $review_reminders_description .= __( 'Create as many reminders as you\'d like using the table above.', 'ultimate-reviews' );
    $review_reminders_description .= '</li><li>';
    $review_reminders_description .= __( 'Reminder Interval and Unit combine to set the amount of time after an order has been set to the selected status before a reminder to review is sent out.', 'ultimate-reviews' );
    $review_reminders_description .= '</li><li>';
    $review_reminders_description .= __( 'Reminders can be stopped for a specific order by going to the WooCommerce "Orders" tab and unselecting the "Send Reminders" checkbox.', 'ultimate-reviews' );
    $review_reminders_description .= '</li><li>';
    $review_reminders_description .= __( 'Alternatively, reminders will automatically stop if "Review Codes" are required for your site, and the code for a specific order is used.', 'ultimate-reviews' );
    $review_reminders_description .= '</li></ul>';

    $filtered_emails_array = array();
    foreach ( ewd_urp_decode_infinite_table_setting( $ewdurpSettings->get_setting( 'email-messages-array' ) ) as $email_message ) { $filtered_emails_array[ $email_message->id ] = $email_message->subject; }


    if ( is_plugin_active( 'ultimate-wp-mail/ultimate-wp-mail.php' ) ) {

      $args = array( 
        'post_type'     => 'uwpm_mail_template', 
        'posts_per_page'  => -1 
      );

      $email_posts = get_posts( $args );
      foreach ( $email_posts as $email_post ) { $filtered_emails_array[ -1 * $email_post->ID ] = $email_post->post_title; }
    }

    $reminder_intervals = array( 'immediate' => 'Immediate' );
    for ( $i = 1; $i < 24; $i++ ) { $reminder_intervals[$i] = $i; }

    $woocommerce_statuses = function_exists( 'wc_get_order_statuses' ) ? wc_get_order_statuses() : array();

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-woocommerce-review-reminders',
      'infinite_table',
      array(
        'id'      => 'reminders-array',
        'title'     => __( 'Review Reminders', 'ultimate-reviews' ),
        'add_label'   => __( '+ ADD', 'ultimate-reviews' ),
        'del_label'   => __( 'Delete', 'ultimate-reviews' ),
        'description' => $review_reminders_description,
        'fields'    => array(
          'id' => array(
            'type'    => 'text',
            'label'   => 'Reminder ID',
            'required'  => true
          ),
          'email-to-send' => array(
            'type'    => 'select',
            'label'   => 'Email to Send',
            'required'  => true,
            'options'   => $filtered_emails_array
          ),
          'reminder-interval' => array(
            'type'    => 'select',
            'label'   => 'Reminder Interval',
            'required'  => true,
            'options'   => $reminder_intervals
          ),
          'reminder-unit' => array(
            'type'    => 'select',
            'label'   => 'Reminder Unit',
            'required'  => true,
            'options'   => array(
              'hours'   => __( 'Hours', 'ultimate-reviews' ),
              'days'    => __( 'Days', 'ultimate-reviews' ),
              'weeks'   => __( 'Weeks', 'ultimate-reviews' ),
            )
          ),
          'status' => array(
            'type'    => 'select',
            'label'   => 'Status',
            'required'  => true,
            'options'   => $woocommerce_statuses
          ),
        )
      )
    );

    $email_messages_description = '<ul><li>';
    $email_messages_description .= __( 'What should be in the messages sent to users?', 'ultimate-reviews' );
    $email_messages_description .= '</li><li>';
    $email_messages_description .= __( 'You can use [section]...[/section] and [footer]...[/footer] to split up the content of your email. You can also include a link button, like so: [button link=\'LINK_URL_GOES_HERE\']BUTTON_TEXT[/button], and a link to review each individual item in an order with:[review-items link=\'LINK_URL_TO_SUBMIT_REVIEW_PAGE\']', 'ultimate-reviews' );
    $email_messages_description .= '</li><li>';
    $email_messages_description .= __( 'You can also put [purchase-date] or into the message body or subject, to put in the date of the purchase or the review code for the purchase, respectively.', 'ultimate-reviews' );
    $email_messages_description .= '</li><li>';
    $email_messages_description .= __( 'Use the area below to send yourself a sample email.', 'ultimate-reviews' );
    $email_messages_description .= '</li></ul>';

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-woocommerce-review-reminders',
      'infinite_table',
      array(
        'id'      => 'email-messages-array',
        'title'     => __( 'Email Messages', 'ultimate-reviews' ),
        'add_label'   => __( '+ ADD', 'ultimate-reviews' ),
        'del_label'   => __( 'Delete', 'ultimate-reviews' ),
        'description' => $email_messages_description,
        'fields'    => array(
          'id' => array(
            'type'    => 'text',
            'label'   => 'Message ID',
            'required'  => true
          ),
          'subject' => array(
            'type'    => 'text',
            'label'   => __( 'Message Subject', 'ultimate-reviews' ),
            'required'  => true
          ),
          'message' => array(
            'type'    => 'textarea',
            'label'   => __( 'Message', 'ultimate-reviews' ),
            'required'  => true
          )
        )
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-woocommerce-review-reminders',
      'select',
      array(
        'id'            => 'send-sample-email-message',
        'title'         => __( 'Sample Email Message', 'ultimate-reviews' ),
        'description' => __( 'Choose an email message to send as a sample.', 'ultimate-reviews' ),
        'blank_option'  => false,
        'options'       => $filtered_emails_array
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-woocommerce-review-reminders',
      'text',
      array(
        'id'            => 'send-sample-email-address',
        'title'         => __( 'Sample Email Address', 'ultimate-reviews' ),
        'description' => __( 'Choose an email address to send the above sample email message to. Make sure that you click the "Save Changes" button below before sending the test message, to receive the most recent version of your email.' )
      )
    );

    $sap->add_section(
      'ewd-urp-settings',
      array_merge(
        array(
          'id'            => 'ewd-urp-woocommerce-reminder-email-styling',
          'title'         => __( 'Review Reminder Styling', 'ultimate-reviews' ),
          'tab'         => 'ewd-urp-woocommerce-tab',
        ),
        $this->get_permission( 'woocommerce' )
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-woocommerce-reminder-email-styling',
      'colorpicker',
      array(
        'id'      => 'styling-email-background-color',
        'title'     => __( 'Email Background Color', 'ultimate-reviews' )
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-woocommerce-reminder-email-styling',
      'colorpicker',
      array(
        'id'      => 'styling-email-inner-color',
        'title'     => __( 'Email Inner Background Color', 'ultimate-reviews' )
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-woocommerce-reminder-email-styling',
      'colorpicker',
      array(
        'id'      => 'styling-email-text-color',
        'title'     => __( 'Email Text Color', 'ultimate-reviews' )
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-woocommerce-reminder-email-styling',
      'colorpicker',
      array(
        'id'      => 'styling-email-button-background-color',
        'title'     => __( 'Button Background Color', 'ultimate-reviews' )
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-woocommerce-reminder-email-styling',
      'colorpicker',
      array(
        'id'      => 'styling-email-button-text-color',
        'title'     => __( 'Button Text Color', 'ultimate-reviews' )
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-woocommerce-reminder-email-styling',
      'colorpicker',
      array(
        'id'      => 'styling-email-button-bg-hover-color',
        'title'     => __( 'Button Hover Background Color', 'ultimate-reviews' )
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-woocommerce-reminder-email-styling',
      'colorpicker',
      array(
        'id'      => 'styling-email-button-text-hover-color',
        'title'     => __( 'Button Hover Text Color', 'ultimate-reviews' )
      )
    );

    return $sap;
  }

  // "Labelling" Tab
  public function ewd_urp_settings_labelling_tab( $sap, $ewdurpSettings ) {
    
    $sap->add_section(
      'ewd-urp-settings',
      array_merge(
        array(
          'id'            => 'ewd-urp-labelling-review-content',
          'title'         => __( 'Review Content', 'ultimate-reviews' ),
          'tab'         => 'ewd-urp-labelling-tab',
        ),
        $this->get_permission( 'labelling' )
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-labelling-review-content',
      'text',
      array(
        'id'            => 'label-posted',
        'title'         => __( 'Posted', 'ultimate-reviews' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-labelling-review-content',
      'text',
      array(
        'id'            => 'label-by',
        'title'         => __( 'By', 'ultimate-reviews' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-labelling-review-content',
      'text',
      array(
        'id'            => 'label-on',
        'title'         => __( 'On', 'ultimate-reviews' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-labelling-review-content',
      'text',
      array(
        'id'            => 'label-score',
        'title'         => __( 'Score', 'ultimate-reviews' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-labelling-review-content',
      'text',
      array(
        'id'            => 'label-explanation',
        'title'         => __( 'Explanation', 'ultimate-reviews' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-labelling-review-content',
      'text',
      array(
        'id'            => 'label-review-for',
        'title'         => __( 'Review for', 'ultimate-reviews' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-labelling-review-content',
      'text',
      array(
        'id'            => 'label-categories',
        'title'         => __( 'Categories', 'ultimate-reviews' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-labelling-review-content',
      'text',
      array(
        'id'            => 'label-verified-buyers',
        'title'         => __( 'Verified Buyer', 'ultimate-reviews' ),
        'description' => ''
      )
    );

    $sap->add_section(
      'ewd-urp-settings',
      array_merge(
        array(
          'id'            => 'ewd-urp-labelling-filtering-area',
          'title'         => __( 'Filtering Area', 'ultimate-reviews' ),
          'tab'         => 'ewd-urp-labelling-tab',
        ),
        $this->get_permission( 'labelling' )
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-labelling-filtering-area',
      'text',
      array(
        'id'            => 'label-filter-button',
        'title'         => __( 'Filter (button)', 'ultimate-reviews' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-labelling-filtering-area',
      'text',
      array(
        'id'            => 'label-filter-product-name',
        'title'         => __( 'Product Name', 'ultimate-reviews' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-labelling-filtering-area',
      'text',
      array(
        'id'            => 'label-filter-all',
        'title'         => __( 'All', 'ultimate-reviews' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-labelling-filtering-area',
      'text',
      array(
        'id'            => 'label-filter-review-score',
        'title'         => __( 'Review Score', 'ultimate-reviews' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-labelling-filtering-area',
      'text',
      array(
        'id'            => 'label-filter-review-author',
        'title'         => __( 'Review Author', 'ultimate-reviews' ),
        'description' => ''
      )
    );

    $sap->add_section(
      'ewd-urp-settings',
      array_merge(
        array(
          'id'            => 'ewd-urp-labelling-submit-reviews',
          'title'         => __( 'Submit Reviews', 'ultimate-reviews' ),
          'tab'         => 'ewd-urp-labelling-tab',
        ),
        $this->get_permission( 'labelling' )
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-labelling-submit-reviews',
      'text',
      array(
        'id'            => 'label-submit-product',
        'title'         => __( 'Product Name', 'ultimate-reviews' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-labelling-submit-reviews',
      'text',
      array(
        'id'            => 'label-submit-author',
        'title'         => __( 'Review Author', 'ultimate-reviews' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-labelling-submit-reviews',
      'text',
      array(
        'id'            => 'label-submit-author-comment',
        'title'         => __( 'Author \'Comment\'', 'ultimate-reviews' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-labelling-submit-reviews',
      'text',
      array(
        'id'            => 'label-submit-title',
        'title'         => __( 'Review Title', 'ultimate-reviews' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-labelling-submit-reviews',
      'text',
      array(
        'id'            => 'label-submit-title-comment',
        'title'         => __( 'Title \'Comment\'', 'ultimate-reviews' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-labelling-submit-reviews',
      'text',
      array(
        'id'            => 'label-submit-score',
        'title'         => __( 'Overall Score', 'ultimate-reviews' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-labelling-submit-reviews',
      'text',
      array(
        'id'            => 'label-submit-review',
        'title'         => __( 'Review', 'ultimate-reviews' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-labelling-submit-reviews',
      'text',
      array(
        'id'            => 'label-submit-element-score',
        'title'         => __( 'Element \'Score\'', 'ultimate-reviews' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-labelling-submit-reviews',
      'text',
      array(
        'id'            => 'label-submit-explanation',
        'title'         => __( 'Category \'Explanation\'', 'ultimate-reviews' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-labelling-submit-reviews',
      'text',
      array(
        'id'            => 'label-submit-button',
        'title'         => __( '\'Send Review\' Button', 'ultimate-reviews' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-labelling-submit-reviews',
      'text',
      array(
        'id'            => 'label-submit-reviewer-email-address',
        'title'         => __( 'Reviewer\'s Email Address', 'ultimate-reviews' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-labelling-submit-reviews',
      'text',
      array(
        'id'            => 'label-submit-reviewer-email-address-desc',
        'title'         => __( 'Email Address Instructions', 'ultimate-reviews' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-labelling-submit-reviews',
      'text',
      array(
        'id'            => 'label-submit-image-numbe',
        'title'         => __( 'Image Number', 'ultimate-reviews' ),
        'description' => ''
      )
    );

    $sap->add_section(
      'ewd-urp-settings',
      array_merge(
        array(
          'id'            => 'ewd-urp-labelling-reviews-summary',
          'title'         => __( 'Reviews Summary', 'ultimate-reviews' ),
          'tab'         => 'ewd-urp-labelling-tab',
        ),
        $this->get_permission( 'labelling' )
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-labelling-reviews-summary',
      'text',
      array(
        'id'            => 'label-summary-average-score',
        'title'         => __( 'Average Score', 'ultimate-reviews' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-labelling-reviews-summary',
      'text',
      array(
        'id'            => 'label-summary-ratings',
        'title'         => __( 'Ratings', 'ultimate-reviews' ),
        'description' => ''
      )
    );

    $sap->add_section(
      'ewd-urp-settings',
      array_merge(
        array(
          'id'            => 'ewd-urp-labelling-messages',
          'title'         => __( 'Messages', 'ultimate-reviews' ),
          'tab'         => 'ewd-urp-labelling-tab',
        ),
        $this->get_permission( 'labelling' )
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-labelling-messages',
      'text',
      array(
        'id'            => 'label-submit-success-message',
        'title'         => __( 'Submit Success Message', 'ultimate-reviews' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-labelling-messages',
      'text',
      array(
        'id'            => 'label-submit-draft-message',
        'title'         => __( 'Submit Draft Add On Message', 'ultimate-reviews' ),
        'description' => ''
      )
    );

    return $sap;
  }

  // "Styling" Tab
  public function ewd_urp_settings_styling_tab( $sap, $ewdurpSettings ) {
    
    $sap->add_section(
      'ewd-urp-settings',
      array_merge(
        array(
          'id'            => 'ewd-urp-styling-general',
          'title'         => __( 'General', 'ultimate-reviews' ),
          'tab'         => 'ewd-urp-styling-tab',
        ),
        $this->get_permission( 'styling' )
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-styling-general',
      'toggle',
      array(
        'id'      => 'disable-numerical-score',
        'title'     => __( 'Disable Score Display', 'ultimate-reviews' ),
        'description' => __( 'Should the numerical review score be hidden?', 'ultimate-reviews' ),
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-styling-general',
      'radio',
      array(
        'id'      => 'reviews-skin',
        'title'     => __( 'Review Skin Style', 'ultimate-reviews' ),
        'description' => __( 'What styling skin should the reviews use?', 'ultimate-reviews' ),
        'default'   => $ewdurpSettings->defaults['reviews-skin'],
        'options'   => array(
          'basic'     => __( 'None', 'ultimate-reviews' ),
          'simplestars' => __( 'Simple Stars', 'ultimate-reviews' ),
          'thumbs'    => __( 'Thumbs', 'ultimate-reviews' ),
          'hearts'    => __( 'Hearts', 'ultimate-reviews' ),
          'simplebar'   => __( 'Simple Bar', 'ultimate-reviews' ),
          'colorbar'    => __( 'Color Bar', 'ultimate-reviews' ),
          'circle'    => __( 'Small Circle Graph', 'ultimate-reviews' ),
          'textcircle'  => __( 'Circle Graph with Score', 'ultimate-reviews' ),
        )
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-styling-general',
      'toggle',
      array(
        'id'      => 'review-group-separating-line',
        'title'     => __( 'Review Group Separating Line', 'ultimate-reviews' ),
        'description' => __( 'Add a separating line between each group of reviews (must have "Group By Product" enabled).', 'ultimate-reviews' )
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-styling-general',
      'radio',
      array(
        'id'      => 'indepth-layout',
        'title'     => __( 'In-Depth Review Categories Layout', 'ultimate-reviews' ),
        'description' => __( 'Choose a layout for the display of the different categories when in-depth reviews are enabled.', 'ultimate-reviews' ),
        'default'   => $ewdurpSettings->defaults['indepth-layout'],
        'options'   => array(
          'regular'   => __( 'Regular', 'ultimate-reviews' ),
          'alternating' => __( 'Alternating Background Color', 'ultimate-reviews' ),
        )
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-styling-general',
      'colorpicker',
      array(
        'id'      => 'indepth-layout-alternating-color',
        'title'     => __( 'Alternating Background Color', 'ultimate-reviews' ),
        'description' => __( 'Choose the color for the alternating background, if you have it enabled.', 'ultimate-reviews' )
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-styling-general',
      'radio',
      array(
        'id'      => 'read-more-style',
        'title'     => __( '"Read More" Style', 'ultimate-reviews' ),
        'description' => __( 'In the thumbnail review format, should the "read more" text be a standard link or a button?', 'ultimate-reviews' ),
        'default'   => $ewdurpSettings->defaults['read-more-style'],
        'options'   => array(
          'standardlink'  => __( 'Standard Link', 'ultimate-reviews' ),
          'button'    => __( 'Button', 'ultimate-reviews' ),
        )
      )
    );

    $sap->add_section(
      'ewd-urp-settings',
      array_merge(
        array(
          'id'            => 'ewd-urp-styling-premium-content',
          'title'         => __( 'Premium Content Styling', 'ultimate-reviews' ),
          'tab'         => 'ewd-urp-styling-tab',
        ),
        $this->get_permission( 'styling' )
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-styling-premium-content',
      'colorpicker',
      array(
        'id'      => 'styling-review-title-font-color',
        'title'     => __( 'Review Title Text Color', 'ultimate-reviews' )
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-styling-premium-content',
      'text',
      array(
        'id'            => 'styling-review-title-font',
        'title'         => __( 'Review Title Font Family', 'ultimate-reviews' ),
        'description' => '',
        'small'     => true
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-styling-premium-content',
      'text',
      array(
        'id'            => 'styling-review-title-font-size',
        'title'         => __( 'Review Title Font Size', 'ultimate-reviews' ),
        'description' => '',
        'small'     => true
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-styling-premium-content',
      'text',
      array(
        'id'            => 'styling-review-title-margin',
        'title'         => __( 'Review Title Margin', 'ultimate-reviews' ),
        'description' => '',
        'small'     => true
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-styling-premium-content',
      'text',
      array(
        'id'            => 'styling-review-title-padding',
        'title'         => __( 'Review Title Padding', 'ultimate-reviews' ),
        'description' => '',
        'small'     => true
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-styling-premium-content',
      'colorpicker',
      array(
        'id'      => 'styling-review-content-font-color',
        'title'     => __( 'Review Content Text Color', 'ultimate-reviews' )
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-styling-premium-content',
      'text',
      array(
        'id'            => 'styling-review-content-font',
        'title'         => __( 'Review Content Font Family', 'ultimate-reviews' ),
        'description' => '',
        'small'     => true
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-styling-premium-content',
      'text',
      array(
        'id'            => 'styling-review-content-font-size',
        'title'         => __( 'Review Content Font Size', 'ultimate-reviews' ),
        'description' => '',
        'small'     => true
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-styling-premium-content',
      'text',
      array(
        'id'            => 'styling-review-content-margin',
        'title'         => __( 'Review Content Margin', 'ultimate-reviews' ),
        'description' => '',
        'small'     => true
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-styling-premium-content',
      'text',
      array(
        'id'            => 'styling-review-content-padding',
        'title'         => __( 'Review Content Padding', 'ultimate-reviews' ),
        'description' => '',
        'small'     => true
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-styling-premium-content',
      'colorpicker',
      array(
        'id'      => 'styling-review-date-font-color',
        'title'     => __( 'Review Meta Text Color', 'ultimate-reviews' )
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-styling-premium-content',
      'text',
      array(
        'id'            => 'styling-review-date-font',
        'title'         => __( 'Review Meta Font Family', 'ultimate-reviews' ),
        'description' => '',
        'small'     => true
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-styling-premium-content',
      'text',
      array(
        'id'            => 'styling-review-date-font-size',
        'title'         => __( 'Review Meta Font Size', 'ultimate-reviews' ),
        'description' => '',
        'small'     => true
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-styling-premium-content',
      'text',
      array(
        'id'            => 'styling-review-date-margin',
        'title'         => __( 'Review Meta Margin', 'ultimate-reviews' ),
        'description' => '',
        'small'     => true
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-styling-premium-content',
      'text',
      array(
        'id'            => 'styling-review-date-padding',
        'title'         => __( 'Review Meta Padding', 'ultimate-reviews' ),
        'description' => '',
        'small'     => true
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-styling-premium-content',
      'colorpicker',
      array(
        'id'      => 'styling-review-score-font-color',
        'title'     => __( 'Review Score Text Color', 'ultimate-reviews' )
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-styling-premium-content',
      'text',
      array(
        'id'            => 'styling-review-score-font',
        'title'         => __( 'Review Score Font Family', 'ultimate-reviews' ),
        'description' => '',
        'small'     => true
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-styling-premium-content',
      'text',
      array(
        'id'            => 'styling-review-score-font-size',
        'title'         => __( 'Review Score Font Size', 'ultimate-reviews' ),
        'description' => '',
        'small'     => true
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-styling-premium-content',
      'text',
      array(
        'id'            => 'styling-review-score-margin',
        'title'         => __( 'Review Score Margin', 'ultimate-reviews' ),
        'description' => '',
        'small'     => true
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-styling-premium-content',
      'text',
      array(
        'id'            => 'styling-review-score-padding',
        'title'         => __( 'Review Score Padding', 'ultimate-reviews' ),
        'description' => '',
        'small'     => true
      )
    );

    $sap->add_section(
      'ewd-urp-settings',
      array_merge(
        array(
          'id'            => 'ewd-urp-styling-premium-colors',
          'title'         => __( 'Premium Color Selection', 'ultimate-reviews' ),
          'tab'         => 'ewd-urp-styling-tab',
        ),
        $this->get_permission( 'styling' )
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-styling-premium-colors',
      'colorpicker',
      array(
        'id'      => 'styling-summary-stats-color',
        'title'     => __( 'Summary Statistics', 'ultimate-reviews' )
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-styling-premium-colors',
      'colorpicker',
      array(
        'id'      => 'styling-simple-bar-color',
        'title'     => __( 'Simple Bar', 'ultimate-reviews' )
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-styling-premium-colors',
      'colorpicker',
      array(
        'id'      => 'styling-color-bar-high',
        'title'     => __( 'Color Bar - High', 'ultimate-reviews' )
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-styling-premium-colors',
      'colorpicker',
      array(
        'id'      => 'styling-color-bar-medium',
        'title'     => __( 'Color Bar - Medium', 'ultimate-reviews' )
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-styling-premium-colors',
      'colorpicker',
      array(
        'id'      => 'styling-color-bar-low',
        'title'     => __( 'Color Bar - Low', 'ultimate-reviews' )
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-styling-premium-colors',
      'colorpicker',
      array(
        'id'      => 'styling-review-background-color',
        'title'     => __( 'Review Background', 'ultimate-reviews' )
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-styling-premium-colors',
      'colorpicker',
      array(
        'id'      => 'styling-review-header-background-color',
        'title'     => __( 'Header Background', 'ultimate-reviews' )
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-styling-premium-colors',
      'colorpicker',
      array(
        'id'      => 'styling-review-content-background-color',
        'title'     => __( 'Content Background', 'ultimate-reviews' )
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-styling-premium-colors',
      'colorpicker',
      array(
        'id'      => 'styling-readmore-button-background-color',
        'title'     => __( 'Read More Button Background', 'ultimate-reviews' )
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-styling-premium-colors',
      'colorpicker',
      array(
        'id'      => 'styling-readmore-button-text-color',
        'title'     => __( 'Read More Button Text', 'ultimate-reviews' )
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-styling-premium-colors',
      'colorpicker',
      array(
        'id'      => 'styling-readmore-button-hover-bg-color',
        'title'     => __( 'Read More Button Hover Background', 'ultimate-reviews' )
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-styling-premium-colors',
      'colorpicker',
      array(
        'id'      => 'styling-readmore-button-hover-text-color',
        'title'     => __( 'Read More Button Hover Text', 'ultimate-reviews' )
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-styling-premium-colors',
      'colorpicker',
      array(
        'id'      => 'styling-image-style-background-color',
        'title'     => __( 'Image Style Background', 'ultimate-reviews' )
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-styling-premium-colors',
      'colorpicker',
      array(
        'id'      => 'styling-circle-graph-background-color',
        'title'     => __( 'Circle Graph Background', 'ultimate-reviews' )
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-styling-premium-colors',
      'colorpicker',
      array(
        'id'      => 'styling-circle-graph-fill-color',
        'title'     => __( 'Circle Graph Fill', 'ultimate-reviews' )
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-styling-premium-colors',
      'colorpicker',
      array(
        'id'      => 'styling-rating-stars-color',
        'title'     => __( 'Rating Stars', 'ultimate-reviews' )
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-styling-premium-colors',
      'colorpicker',
      array(
        'id'      => 'styling-verified-checkmark-bg-color',
        'title'     => __( 'Verified Buyer Badge Background', 'ultimate-reviews' )
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-styling-premium-colors',
      'colorpicker',
      array(
        'id'      => 'styling-verified-checkmark-color',
        'title'     => __( 'Verified Buyer Badge Checkmark', 'ultimate-reviews' )
      )
    );

    $sap->add_setting(
      'ewd-urp-settings',
      'ewd-urp-styling-premium-colors',
      'colorpicker',
      array(
        'id'      => 'styling-verified-checkmark-text-color',
        'title'     => __( 'Verified Buyer Badge Text', 'ultimate-reviews' )
      )
    );
    
    return $sap;
  }

}
}