<?php
if ( ! defined( 'ABSPATH' ) ) exit;

if ( !class_exists( 'ewdusEWDPHSettings' ) ) {
class ewdusEWDPHSettings {

  public function __construct() {

    add_filter( 'ewd_us_defaults', array( $this, 'ewd_us_settings_set_defaults' ), 10, 2 );

    add_filter( 'ewd_us_settings_page', array( $this, 'ewd_us_settings__non_premium_tabs' ), 10, 2 );

    add_filter( 'ewd_us_settings_page', array( $this, 'ewd_us_settings_premium_tab' ), 10, 2 );
    add_filter( 'ewd_us_settings_page', array( $this, 'ewd_us_settings_styling_tab' ), 10, 2 );
    add_filter( 'ewd_us_settings_page', array( $this, 'ewd_us_settings_controls_tab' ), 10, 2 );
  }

  public function get_permission( $permission_type = '' ) {
    global $ewd_us_controller;
  
    $ewd_us_premium_permissions = array();
  
    if ( ! $ewd_us_controller->permissions->check_permission( $permission_type ) ) {
      $ewd_us_premium_permissions = array(
        'disabled'    => true,
        'disabled_image'=> '#',
        'purchase_link' => 'https://www.etoilewebdesign.com/plugins/ultimate-slider/?utm_source=us_lockbox'
      );
    }
  
    return $ewd_us_premium_permissions;
  }

  public function ewd_us_settings_set_defaults( $defaults, $ewdusSettings ) {

    $defaults = array_merge(
      $defaults,
      array(
        // Any default which you are certain that won't be used for free version.
      )
    );
  
    return $defaults;
  }

  public function ewd_us_settings__non_premium_tabs( $sap, $ewdusSettings ) {

    return $sap;
  }

  // "Premium" Tab
  public function ewd_us_settings_premium_tab( $sap, $ewdusSettings ) {
    
    $sap->add_section(
      'ewd-us-settings',
      array_merge(
        array(
          'id'            => 'ewd-us-premium-options',
          'title'         => __( 'Premium Options', 'ultimate-slider' ),
          'tab'         => 'ewd-us-premium-tab',
        ),
        $this->get_permission( 'premium' )
      )
    );

    $sap->add_setting(
      'ewd-us-settings',
      'ewd-us-premium-options',
      'radio',
      array(
        'id'      => 'slide-transition-effect',
        'title'     => __( 'Slide Transition Effect', 'ultimate-slider' ),
        'description' => __( 'Which effect should be used to transition between slides?', 'ultimate-slider' ),
        'options'   => array(
          'slide'     => __( 'Default', 'ultimate-slider' ),
          'fade'      => __( 'Fade', 'ultimate-slider' ),
          'slide-up'    => __( 'Slide Up', 'ultimate-slider' ),
          'slide-down'  => __( 'Slide Down', 'ultimate-slider' ),
          'stretch-right' => __( 'Stretch Right', 'ultimate-slider' ),
          'stretch-left'  => __( 'Stretch Left', 'ultimate-slider' ),
          'grow'      => __( 'Grow', 'ultimate-slider' ),
          'expand'    => __( 'Expand', 'ultimate-slider' ),
        )
      )
    );

    $sap->add_setting(
      'ewd-us-settings',
      'ewd-us-premium-options',
      'toggle',
      array(
        'id'      => 'wc-product-image-slider',
        'title'     => __( 'WooCommerce Product Image Slider', 'ultimate-slider' ),
        'description' => __( 'Should the WooCommerce product page image be converted into a slider when there\'s more than one image? (Might require changing the "Aspect Ratio" setting for the slider, depending on the theme you\'re using)', 'ultimate-slider' )
      )
    );

    $sap->add_setting(
      'ewd-us-settings',
      'ewd-us-premium-options',
      'select',
      array(
        'id'            => 'mobile-aspect-ratio',
        'title'         => __( 'Mobile Aspect Ratio', 'ultimate-slider' ),
        'description'   => __( 'What should the aspect ratio of the slider be on smaller screens?', 'ultimate-slider' ),
        'blank_option'  => false,
        'default'     => $ewdusSettings->defaults['mobile-aspect-ratio'],
        'options'       => array(
          '3_1'     => '3:1',
          '16_7'      => '16:7' . __( '(default)', 'ultimate-slider' ),
          '2_1'     => '2:1',
          '16_9'      => '16:9',
          '3_2'     => '3:2',
          '4_3'     => '4:3',
          '1_1'     => '1:1',
        )
      )
    );

    $sap->add_setting(
      'ewd-us-settings',
      'ewd-us-premium-options',
      'checkbox',
      array(
        'id'      => 'hide-from-slider',
        'title'     => __( 'Hide Elements from Slider', 'ultimate-slider' ),
        'description' => __( 'Hide specific elements of the slider.', 'ultimate-slider' ),
        'options'   => array(
          'title'     => 'Title',
          'body'      => 'Body',
          'buttons'   => 'Buttons',
          'arrows'    => 'Arrows',
        )
      )
    );

    $sap->add_setting(
      'ewd-us-settings',
      'ewd-us-premium-options',
      'checkbox',
      array(
        'id'      => 'hide-on-mobile',
        'title'     => __( 'Hide Elements from Mobile View', 'ultimate-slider' ),
        'description' => __( 'Hide elements just from the mobile view.', 'ultimate-slider' ),
        'options'   => array(
          'title'     => 'Title',
          'body'      => 'Body',
          'buttons'   => 'Buttons',
          'arrows'    => 'Arrows',
          'thumbnails'  => 'Thumbnails',
        )
      )
    );

    $sap->add_setting(
      'ewd-us-settings',
      'ewd-us-premium-options',
      'toggle',
      array(
        'id'      => 'mobile-link-to-full',
        'title'     => __( 'Mobile Link to Full Post?', 'ultimate-slider' ),
        'description' => __( 'Should clicking on a slide bring up the individual slide post on mobile?', 'ultimate-slider' )
      )
    );

    $sap->add_setting(
      'ewd-us-settings',
      'ewd-us-premium-options',
      'radio',
      array(
        'id'      => 'title-animate',
        'title'     => __( 'Title Animation', 'ultimate-slider' ),
        'description' => '',
        'options'   => array(
          'none'        => __( 'None', 'ultimate-slider' ),
          'slidefromleft'   => __( 'Slide From Left', 'ultimate-slider' ),
          'slidefromright'  => __( 'Slide From Right', 'ultimate-slider' ),
          'fadein'      => __( 'Fade In', 'ultimate-slider' ),
          'scrolldown'    => __( 'Scroll Down', 'ultimate-slider' ),
        )
      )
    );

    $sap->add_setting(
      'ewd-us-settings',
      'ewd-us-premium-options',
      'toggle',
      array(
        'id'      => 'force-full-width',
        'title'     => __( 'Force Full Width', 'ultimate-slider' ),
        'description' => __( 'Force the slider to go the full width of the window, regardless of the container it\'s in.', 'ultimate-slider' )
      )
    );

    $sap->add_setting(
      'ewd-us-settings',
      'ewd-us-premium-options',
      'toggle',
      array(
        'id'      => 'add-watermark',
        'title'     => __( 'Add Watermark', 'ultimate-slider' ),
        'description' => __( 'Should a watermark be added to each image? Requires GD PHP module to be installed on your server.', 'ultimate-slider' )
      )
    );

    $sap->add_setting(
      'ewd-us-settings',
      'ewd-us-premium-options',
      'toggle',
      array(
        'id'      => 'lightbox',
        'title'     => __( 'Lightbox on Image Click', 'ultimate-slider' ),
        'description' => __( 'Should a lightbox be opened when an image is clicked on? Particularly useful if you\'re using carousel mode. Want to customize this lightbox? Install the "Ultimate Lightbox" plugin , and you can switch the lightbox colors, controls, behaviour and more. It\'s free!', 'ultimate-slider' )
      )
    );

    $sap->add_section(
      'ewd-us-settings',
      array_merge(
        array(
          'id'            => 'ewd-us-youtube-options',
          'title'         => __( 'YouTube Slide Options', 'ultimate-slider' ),
          'tab'         => 'ewd-us-premium-tab',
        ),
        $this->get_permission( 'premium' )
      )
    );

    $sap->add_setting(
      'ewd-us-settings',
      'ewd-us-youtube-options',
      'toggle',
      array(
        'id'      => 'youtube-autoplay-video',
        'title'     => __( 'Autoplay Video', 'ultimate-slider' ),
        'description' => __( 'Should the video automatically start playing on page load?', 'ultimate-slider' )
      )
    );

    $sap->add_setting(
      'ewd-us-settings',
      'ewd-us-youtube-options',
      'toggle',
      array(
        'id'      => 'youtube-show-content',
        'title'     => __( 'Show Slide Content', 'ultimate-slider' ),
        'description' => __( 'Enabling this will overlay the slide content on top of the video. Disable it to only show the video.', 'ultimate-slider' )
      )
    );

    $sap->add_setting(
      'ewd-us-settings',
      'ewd-us-youtube-options',
      'text',
      array(
        'id'            => 'youtube-video-opacity',
        'title'         => __( 'Video Opacity', 'ultimate-slider' ),
        'description' => __( 'This lets you set the opacity of the video, which can help if you have the content enabled above. (Examples would be 0, 0.5 or 1.)', 'ultimate-slider' ),
        'small'     => true
      )
    );

    return $sap;
  }

  // "Styling" Tab
  public function ewd_us_settings_styling_tab( $sap, $ewdusSettings ) {
    
    $sap->add_section(
      'ewd-us-settings',
      array_merge(
        array(
          'id'            => 'ewd-us-slide-title-options',
          'title'         => __( 'Slide Title Options', 'ultimate-slider' ),
          'tab'         => 'ewd-us-styling-tab',
        ),
        $this->get_permission( 'styling' )
      )
    );

    $sap->add_setting(
      'ewd-us-settings',
      'ewd-us-slide-title-options',
      'colorpicker',
      array(
        'id'      => 'styling-slide-title-font-color',
        'title'     => __( 'Color', 'ultimate-slider' )
      )
    );

    $sap->add_setting(
      'ewd-us-settings',
      'ewd-us-slide-title-options',
      'text',
      array(
        'id'            => 'styling-slide-title-font',
        'title'         => __( 'Font Family', 'ultimate-slider' ),
        'small'     => true
      )
    );

    $sap->add_setting(
      'ewd-us-settings',
      'ewd-us-slide-title-options',
      'text',
      array(
        'id'            => 'styling-slide-title-font-size',
        'title'         => __( 'Font Size', 'ultimate-slider' ),
        'small'     => true
      )
    );

    $sap->add_section(
      'ewd-us-settings',
      array_merge(
        array(
          'id'            => 'ewd-us-slide-text-options',
          'title'         => __( 'Slide Text Options', 'ultimate-slider' ),
          'tab'         => 'ewd-us-styling-tab',
        ),
        $this->get_permission( 'styling' )
      )
    );

    $sap->add_setting(
      'ewd-us-settings',
      'ewd-us-slide-text-options',
      'colorpicker',
      array(
        'id'      => 'styling-slide-text-font-color',
        'title'     => __( 'Color', 'ultimate-slider' )
      )
    );

    $sap->add_setting(
      'ewd-us-settings',
      'ewd-us-slide-text-options',
      'text',
      array(
        'id'            => 'styling-slide-text-font',
        'title'         => __( 'Font Family', 'ultimate-slider' ),
        'small'     => true
      )
    );

    $sap->add_setting(
      'ewd-us-settings',
      'ewd-us-slide-text-options',
      'text',
      array(
        'id'            => 'styling-slide-text-font-size',
        'title'         => __( 'Font Size', 'ultimate-slider' ),
        'small'     => true
      )
    );

    $sap->add_section(
      'ewd-us-settings',
      array_merge(
        array(
          'id'            => 'ewd-us-slide-button-options',
          'title'         => __( 'Slide Button Options', 'ultimate-slider' ),
          'tab'         => 'ewd-us-styling-tab',
        ),
        $this->get_permission( 'styling' )
      )
    );

    $sap->add_setting(
      'ewd-us-settings',
      'ewd-us-slide-button-options',
      'colorpicker',
      array(
        'id'      => 'styling-button-background-color',
        'title'     => __( 'Background Color', 'ultimate-slider' )
      )
    );

    $sap->add_setting(
      'ewd-us-settings',
      'ewd-us-slide-button-options',
      'colorpicker',
      array(
        'id'      => 'styling-button-background-hover-color',
        'title'     => __( 'Background Hover Color', 'ultimate-slider' )
      )
    );

    $sap->add_setting(
      'ewd-us-settings',
      'ewd-us-slide-button-options',
      'colorpicker',
      array(
        'id'      => 'styling-button-border-color',
        'title'     => __( 'Border Color', 'ultimate-slider' )
      )
    );

    $sap->add_setting(
      'ewd-us-settings',
      'ewd-us-slide-button-options',
      'colorpicker',
      array(
        'id'      => 'styling-button-border-hover-color',
        'title'     => __( 'Border Hover Color', 'ultimate-slider' )
      )
    );

    $sap->add_setting(
      'ewd-us-settings',
      'ewd-us-slide-button-options',
      'colorpicker',
      array(
        'id'      => 'styling-button-text-color',
        'title'     => __( 'Text Color', 'ultimate-slider' )
      )
    );

    $sap->add_setting(
      'ewd-us-settings',
      'ewd-us-slide-button-options',
      'colorpicker',
      array(
        'id'      => 'styling-button-text-hover-color',
        'title'     => __( 'Text Hover Color', 'ultimate-slider' )
      )
    );

    return $sap;
  }

  // "Controls" Tab
  public function ewd_us_settings_controls_tab( $sap, $ewdusSettings ) {
    
    $sap->add_section(
      'ewd-us-settings',
      array_merge(
        array(
          'id'            => 'ewd-us-control-options',
          'title'         => __( 'Control Options', 'ultimate-slider' ),
          'tab'         => 'ewd-us-controls-tab',
        ),
        $this->get_permission( 'controls' )
      )
    );

    $sap->add_setting(
      'ewd-us-settings',
      'ewd-us-control-options',
      'radio',
      array(
        'id'      => 'arrow',
        'title'     => __( 'Arrows', 'ultimate-slider' ),
        'columns'   => '3',
        'options'   => array(
          'none'      => __( 'No Arrow', 'ultimate-slider' ),
          'a'       => '<span class="ewd-us-arrow">b</span>',
          'c'       => '<span class="ewd-us-arrow">d</span>',
          'e'       => '<span class="ewd-us-arrow">f</span>',
          'g'       => '<span class="ewd-us-arrow">h</span>',
          'i'       => '<span class="ewd-us-arrow">j</span>',
          'k'       => '<span class="ewd-us-arrow">l</span>',
          'm'       => '<span class="ewd-us-arrow">n</span>',
          'o'       => '<span class="ewd-us-arrow">p</span>',
          'q'       => '<span class="ewd-us-arrow">r</span>',
          'A'       => '<span class="ewd-us-arrow">B</span>',
          'E'       => '<span class="ewd-us-arrow">D</span>',
          'G'       => '<span class="ewd-us-arrow">F</span>',
          'I'       => '<span class="ewd-us-arrow">J</span>',
          'K'       => '<span class="ewd-us-arrow">L</span>',
          'M'       => '<span class="ewd-us-arrow">N</span>',
          'O'       => '<span class="ewd-us-arrow">P</span>',
          'Q'       => '<span class="ewd-us-arrow">R</span>',
        )
      )
    );

    $sap->add_setting(
      'ewd-us-settings',
      'ewd-us-control-options',
      'radio',
      array(
        'id'      => 'arrow-background-shape',
        'title'     => __( 'Background Shape', 'ultimate-slider' ),
        'description' => '',
        'options'   => array(
          'none'      => __( 'No Background', 'ultimate-slider' ),
          'square'    => __( 'Square', 'ultimate-slider' ),
          'circle'    => __( 'Circle', 'ultimate-slider' ),
          'diamond'   => __( 'Diamond', 'ultimate-slider' ),
        )
      )
    );

    $sap->add_setting(
      'ewd-us-settings',
      'ewd-us-control-options',
      'colorpicker',
      array(
        'id'      => 'styling-arrow-color',
        'title'     => __( 'Arrow Color', 'ultimate-slider' )
      )
    );

    $sap->add_setting(
      'ewd-us-settings',
      'ewd-us-control-options',
      'colorpicker',
      array(
        'id'      => 'styling-arrow-background-color',
        'title'     => __( 'Arrow Background Color', 'ultimate-slider' )
      )
    );

    $sap->add_setting(
      'ewd-us-settings',
      'ewd-us-control-options',
      'colorpicker',
      array(
        'id'      => 'styling-clickable-area-background-color',
        'title'     => __( 'Clickable Area Color', 'ultimate-slider' )
      )
    );

    $sap->add_setting(
      'ewd-us-settings',
      'ewd-us-control-options',
      'text',
      array(
        'id'            => 'styling-arrow-font-size',
        'title'         => __( 'Arrow Size', 'ultimate-slider' ),
        'small'     => true
      )
    );

    $sap->add_setting(
      'ewd-us-settings',
      'ewd-us-control-options',
      'text',
      array(
        'id'            => 'styling-arrow-background-size',
        'title'         => __( 'Arrow Background Size', 'ultimate-slider' ),
        'small'     => true
      )
    );

    $sap->add_setting(
      'ewd-us-settings',
      'ewd-us-control-options',
      'text',
      array(
        'id'            => 'styling-clickable-area-size',
        'title'         => __( 'Clickable Area Size', 'ultimate-slider' ),
        'small'     => true
      )
    );

    $sap->add_setting(
      'ewd-us-settings',
      'ewd-us-control-options',
      'text',
      array(
        'id'            => 'styling-arrow-line-height',
        'title'         => __( 'Line Height of Arrow Within Background (ex. "1.25")', 'ultimate-slider' ),
        'small'     => true
      )
    );
    
    return $sap;
  }

}
}