<?php
if ( ! defined( 'ABSPATH' ) ) exit;

if ( !class_exists( 'ewduwcfEWDPHSettings' ) ) {
class ewduwcfEWDPHSettings {

  public function __construct() {

    add_filter( 'ewd_uwcf_defaults', array( $this, 'ewd_uwcf_settings_set_defaults' ), 10, 2 );

    add_filter( 'ewd_uwcf_settings_page', array( $this, 'ewd_uwcf_settings__non_premium_tabs' ), 10, 2 );

    add_filter( 'ewd_uwcf_settings_page', array( $this, 'ewd_uwcf_settings_scheduling_tab' ), 10, 2 );
    add_filter( 'ewd_uwcf_settings_page', array( $this, 'ewd_uwcf_settings_labelling_tab' ), 10, 2 );
    add_filter( 'ewd_uwcf_settings_page', array( $this, 'ewd_uwcf_settings_styling_tab' ), 10, 2 );
  }

  public function get_permission( $permission_type = '' ) {
    global $ewd_uwcf_controller;
  
    $ewd_uwcf_premium_permissions = array();
  
    if ( ! $ewd_uwcf_controller->permissions->check_permission( $permission_type ) ) {
      $ewd_uwcf_premium_permissions = array(
        'disabled'    => true,
        'disabled_image'=> '#',
        'purchase_link' => 'https://www.etoilewebdesign.com/plugins/woocommerce-filters/?utm_source=uwcf_lockbox'
      );
    }
  
    return $ewd_uwcf_premium_permissions;
  }

  public function ewd_uwcf_settings_set_defaults( $defaults, $ewduwcfSettings ) {

    $defaults = array_merge(
      $defaults,
      array(
        // Any default which you are certain that won't be used for free version.
      )
    );
  
    return $defaults;
  }

  public function ewd_uwcf_settings__non_premium_tabs( $sap, $ewduwcfSettings ) {

    //Add settings for bottoms of each section here

    return $sap;
  }

  // "Labelling" Tab
  public function ewd_uwcf_settings_scheduling_tab( $sap, $ewduwcfSettings ) {
    
    $sap->add_section(
      'ewd-uwcf-settings',
      array_merge(
        array(
          'id'            => 'ewd-uwcf-scheduling',
          'title'         => __( 'Scheduling', 'color-filters' ),
          'tab'         => 'ewd-uwcf-scheduling-tab',
        ),
        $this->get_permission( 'scheduling' )
      )
    );

    $sap->add_setting(
      'ewd-uwcf-settings',
      'ewd-uwcf-scheduling',
      'toggle',
      array(
        'id'          => 'disable-ordering',
        'title'       => __( 'Disable All Ordering', 'color-filters' ),
        'description' => __( 'Disable all WooCommerce ordering on the site until this toggle is turned off.', 'color-filters' )
      )
    );

    $sap->add_setting(
      'ewd-uwcf-settings',
      'ewd-uwcf-scheduling',
      'toggle',
      array(
        'id'          => 'enable-scheduling',
        'title'       => __( 'Enable Scheduling', 'color-filters' ),
        'description' => __( 'Enable the scheduling rules below to determine when ordering should be available. Ordering will be disabled at other times.', 'color-filters' )
      )
    );

    // Translateable strings for scheduler components
    $scheduler_strings = array(
      'add_rule'        => __( 'Add new scheduling rule', 'color-filters' ),
      'weekly'          => _x( 'Weekly', 'Format of a scheduling rule', 'color-filters' ),
      'monthly'         => _x( 'Monthly', 'Format of a scheduling rule', 'color-filters' ),
      'date'            => _x( 'Date', 'Format of a scheduling rule', 'color-filters' ),
      'date_range'      => _x( 'Date Range', 'Format of a scheduling rule', 'color-filters' ),
      'weekdays'        => _x( 'Days of the week', 'Label for selecting days of the week in a scheduling rule', 'color-filters' ),
      'month_weeks'     => _x( 'Weeks of the month', 'Label for selecting weeks of the month in a scheduling rule', 'color-filters' ),
      'date_label'      => _x( 'Date', 'Label to select a date for a scheduling rule', 'color-filters' ),
      'time_label'      => _x( 'Time', 'Label to select a time slot for a scheduling rule', 'color-filters' ),
      'allday'          => _x( 'All day', 'Label to set a scheduling rule to last all day', 'color-filters' ),
      'start'           => _x( 'Start', 'Label for the starting date/time of a scheduling rule', 'color-filters' ),
      'end'             => _x( 'End', 'Label for the ending date/time of a scheduling rule', 'color-filters' ),
      'set_time_prompt' => _x( 'All day long. Want to %sset a time slot%s?', 'Prompt displayed when a scheduling rule is set without any time restrictions', 'color-filters' ),
      'toggle'          => _x( 'Open and close this rule', 'Toggle a scheduling rule open and closed', 'color-filters' ),
      'delete'          => _x( 'Delete rule', 'Delete a scheduling rule', 'color-filters' ),
      'delete_schedule' => __( 'Delete scheduling rule', 'color-filters' ),
      'never'           => _x( 'Never', 'Brief default description of a scheduling rule when no weekdays or weeks are included in the rule', 'color-filters' ),
      'weekly_always'   => _x( 'Every day', 'Brief default description of a scheduling rule when all the weekdays/weeks are included in the rule', 'color-filters' ),
      'monthly_weekdays'=> _x( '%s on the %s week of the month', 'Brief default description of a scheduling rule when some weekdays are included on only some weeks of the month. %s should be left alone and will be replaced by a comma-separated list of days and weeks in the following format: M, T, W on the first, second week of the month', 'color-filters' ),
      'monthly_weeks'   => _x( '%s week of the month', 'Brief default description of a scheduling rule when some weeks of the month are included but all or no weekdays are selected. %s should be left alone and will be replaced by a comma-separated list of weeks in the following format: First, second week of the month', 'color-filters' ),
      'all_day'         => _x( 'All day', 'Brief default description of a scheduling rule when no times are set', 'color-filters' ),
      'before'          => _x( 'Ends at', 'Brief default description of a scheduling rule when an end time is set but no start time. If the end time is 6pm, it will read: Ends at 6pm', 'color-filters' ),
      'after'           => _x( 'Starts at', 'Brief default description of a scheduling rule when a start time is set but no end time. If the start time is 6pm, it will read: Starts at 6pm', 'color-filters' ),
      'separator'       => _x( '&mdash;', 'Separator between times of a scheduling rule', 'color-filters' ),
      'date_range_from_today' => _x( 'From Today', 'When Date range start date is not set', 'color-filters' ),
      'date_range_upto_indefinite' => _x( 'Upto Indefinite', 'When Date range end date is not set', 'color-filters' ),
    );

    $sap->add_setting(
      'ewd-uwcf-settings',
      'ewd-uwcf-scheduling',
      'scheduler',
      array(
        'id'      => 'schedule-open',
        'title'     => __( 'Schedule', 'color-filters' ),
        'description' => __( 'Define the weekly schedule during which you accept bookings.', 'color-filters' ),
        'weekdays'    => array(
          'monday'    => _x( 'Mo', 'Monday abbreviation', 'color-filters' ),
          'tuesday'   => _x( 'Tu', 'Tuesday abbreviation', 'color-filters' ),
          'wednesday'   => _x( 'We', 'Wednesday abbreviation', 'color-filters' ),
          'thursday'    => _x( 'Th', 'Thursday abbreviation', 'color-filters' ),
          'friday'    => _x( 'Fr', 'Friday abbreviation', 'color-filters' ),
          'saturday'    => _x( 'Sa', 'Saturday abbreviation', 'color-filters' ),
          'sunday'    => _x( 'Su', 'Sunday abbreviation', 'color-filters' )
        ),
        'time_format' => 'h:i A',
        'date_format' => 'mmmm d, yyyy',
        'disable_weeks' => true,
        'disable_date'  => true,
        'disable_date_range'  => true,
        'strings' => $scheduler_strings,
      )
    );

    $scheduler_strings['add_day'] = _x( 'Closed all day', 'Brief default description of a scheduling exception when no times are set', 'color-filters' );

    $sap->add_setting(
      'ewd-uwcf-settings',
      'ewd-uwcf-scheduling',
      'scheduler',
      array(
        'id'        => 'schedule-closed',
        'title'       => __( 'Exceptions', 'color-filters' ),
        'description'   => __( "Define special opening hours for holidays, events or other needs. Leave the time empty to close ordering all day.", 'color-filters' ),
        'time_format'   => 'h:i A',
        'date_format'   => 'mmmm d, yyyy',
        'disable_weekdays'  => true,
        'disable_weeks'   => true,
        'strings' => $scheduler_strings,
      )
    );

    $sap->add_setting(
      'ewd-uwcf-settings',
      'ewd-uwcf-scheduling',
      'toggle',
      array(
        'id'          => 'disable-read-more',
        'title'       => __( 'Disable Read More', 'color-filters' ),
        'description' => __( 'Disable the \'Read More\' text that automatically gets added when ordering is disabled.', 'color-filters' )
      )
    );

    $sap->add_setting(
      'ewd-uwcf-settings',
      'ewd-uwcf-scheduling',
      'toggle',
      array(
        'id'          => 'disable-prices',
        'title'       => __( 'Disable Prices', 'color-filters' ),
        'description' => __( 'Disable the price display on the shop, product and archive pages.', 'color-filters' )
      )
    );

    return $sap;
  }

  // "Labelling" Tab
  public function ewd_uwcf_settings_labelling_tab( $sap, $ewduwcfSettings ) {
    
    $sap->add_section(
      'ewd-uwcf-settings',
      array_merge(
        array(
          'id'            => 'ewd-uwcf-labelling-widget-and-shortcode',
          'title'         => __( 'Widget & Shortcode', 'color-filters' ),
          'tab'         => 'ewd-uwcf-labelling-tab',
        ),
        $this->get_permission( 'labelling' )
      )
    );

    $sap->add_setting(
      'ewd-uwcf-settings',
      'ewd-uwcf-labelling-widget-and-shortcode',
      'text',
      array(
        'id'            => 'label-show-all-color',
        'title'         => __( 'Show All Colors', 'color-filters' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-uwcf-settings',
      'ewd-uwcf-labelling-widget-and-shortcode',
      'text',
      array(
        'id'            => 'label-show-all-size',
        'title'         => __( 'Show All Sizes', 'color-filters' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-uwcf-settings',
      'ewd-uwcf-labelling-widget-and-shortcode',
      'text',
      array(
        'id'            => 'label-show-all-category',
        'title'         => __( 'Show All Categories', 'color-filters' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-uwcf-settings',
      'ewd-uwcf-labelling-widget-and-shortcode',
      'text',
      array(
        'id'            => 'label-show-all-tag',
        'title'         => __( 'Show All Tags', 'color-filters' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-uwcf-settings',
      'ewd-uwcf-labelling-widget-and-shortcode',
      'text',
      array(
        'id'            => 'label-show-all-attribute',
        'title'         => __( 'Show All Attributes', 'color-filters' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-uwcf-settings',
      'ewd-uwcf-labelling-widget-and-shortcode',
      'text',
      array(
        'id'            => 'label-ratings',
        'title'         => __( 'Rating', 'color-filters' ),
        'description' => ''
      )
    );

    $sap->add_section(
      'ewd-uwcf-settings',
      array_merge(
        array(
          'id'            => 'ewd-uwcf-labelling-product-thumbnail',
          'title'         => __( 'Product Thumbnail', 'color-filters' ),
          'tab'         => 'ewd-uwcf-labelling-tab',
        ),
        $this->get_permission( 'labelling' )
      )
    );

    $sap->add_setting(
      'ewd-uwcf-settings',
      'ewd-uwcf-labelling-product-thumbnail',
      'text',
      array(
        'id'            => 'label-thumbnail-colors',
        'title'         => __( 'Colors', 'color-filters' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-uwcf-settings',
      'ewd-uwcf-labelling-product-thumbnail',
      'text',
      array(
        'id'            => 'label-thumbnail-sizes',
        'title'         => __( 'Sizes', 'color-filters' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-uwcf-settings',
      'ewd-uwcf-labelling-product-thumbnail',
      'text',
      array(
        'id'            => 'label-thumbnail-categories',
        'title'         => __( 'Categories', 'color-filters' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-uwcf-settings',
      'ewd-uwcf-labelling-product-thumbnail',
      'text',
      array(
        'id'            => 'label-thumbnail-tags',
        'title'         => __( 'Tags', 'color-filters' ),
        'description' => ''
      )
    );

    $sap->add_section(
      'ewd-uwcf-settings',
      array_merge(
        array(
          'id'            => 'ewd-uwcf-labelling-product-page',
          'title'         => __( 'Product Page', 'color-filters' ),
          'tab'         => 'ewd-uwcf-labelling-tab',
        ),
        $this->get_permission( 'labelling' )
      )
    );

    $sap->add_setting(
      'ewd-uwcf-settings',
      'ewd-uwcf-labelling-product-page',
      'text',
      array(
        'id'            => 'label-product-page-colors',
        'title'         => __( 'Colors', 'color-filters' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-uwcf-settings',
      'ewd-uwcf-labelling-product-page',
      'text',
      array(
        'id'            => 'label-product-page-sizes',
        'title'         => __( 'Sizes', 'color-filters' ),
        'description' => ''
      )
    );

    return $sap;
  }

  // "Styling" Tab
  public function ewd_uwcf_settings_styling_tab( $sap, $ewduwcfSettings ) {
    
    $sap->add_section(
      'ewd-uwcf-settings',
      array_merge(
        array(
          'id'            => 'ewd-uwcf-styling-widget-and-shortcode',
          'title'         => __( 'Widget and Shortcode', 'color-filters' ),
          'tab'         => 'ewd-uwcf-styling-tab',
        ),
        $this->get_permission( 'styling' )
      )
    );

    $sap->add_setting(
      'ewd-uwcf-settings',
      'ewd-uwcf-styling-widget-and-shortcode',
      'radio',
      array(
        'id'      => 'styling-color-filter-shape',
        'title'     => __( 'Color Shape', 'color-filters' ),
        'description' => '',
        'options'   => array(
          'circle'    => __( 'Circle', 'color-filters' ),
          'square'    => __( 'Square', 'color-filters' ),
        ),
        'default'   => $ewduwcfSettings->defaults['styling-color-filter-shape']
      )
    );

    $sap->add_setting(
      'ewd-uwcf-settings',
      'ewd-uwcf-styling-widget-and-shortcode',
      'text',
      array(
        'id'            => 'styling-color-icon-size',
        'title'         => __( 'Color Icons Width', 'color-filters' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-uwcf-settings',
      'ewd-uwcf-styling-widget-and-shortcode',
      'colorpicker',
      array(
        'id'      => 'styling-widget-font-color',
        'title'     => __( 'Font Options Color', 'ultimate-slider' )
      )
    );

    $sap->add_setting(
      'ewd-uwcf-settings',
      'ewd-uwcf-styling-widget-and-shortcode',
      'text',
      array(
        'id'            => 'styling-widget-font-size',
        'title'         => __( 'Font Options Font Size', 'color-filters' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-uwcf-settings',
      'ewd-uwcf-styling-widget-and-shortcode',
      'colorpicker',
      array(
        'id'      => 'styling-ratings-bar-fill-color',
        'title'     => __( 'Ratings Bar/Price Slider Fill Color', 'ultimate-slider' )
      )
    );

    $sap->add_setting(
      'ewd-uwcf-settings',
      'ewd-uwcf-styling-widget-and-shortcode',
      'colorpicker',
      array(
        'id'      => 'styling-ratings-bar-empty-color',
        'title'     => __( 'Ratings Bar/Price Slider Empty Color', 'ultimate-slider' )
      )
    );

    $sap->add_setting(
      'ewd-uwcf-settings',
      'ewd-uwcf-styling-widget-and-shortcode',
      'colorpicker',
      array(
        'id'      => 'styling-ratings-bar-handle-color',
        'title'     => __( 'Ratings Bar/Price Slider Handles Color', 'ultimate-slider' )
      )
    );

    $sap->add_setting(
      'ewd-uwcf-settings',
      'ewd-uwcf-styling-widget-and-shortcode',
      'colorpicker',
      array(
        'id'      => 'styling-ratings-bar-text-color',
        'title'     => __( 'Ratings Bar/Price Slider Text Color', 'ultimate-slider' )
      )
    );

    $sap->add_setting(
      'ewd-uwcf-settings',
      'ewd-uwcf-styling-widget-and-shortcode',
      'text',
      array(
        'id'            => 'styling-ratings-bar-font-size',
        'title'         => __( 'Ratings Bar/Price Slider Font Size', 'color-filters' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-uwcf-settings',
      'ewd-uwcf-styling-widget-and-shortcode',
      'colorpicker',
      array(
        'id'      => 'styling-reset-all-button-background-color',
        'title'     => __( 'Reset All Button Background Color', 'ultimate-slider' )
      )
    );

    $sap->add_setting(
      'ewd-uwcf-settings',
      'ewd-uwcf-styling-widget-and-shortcode',
      'colorpicker',
      array(
        'id'      => 'styling-reset-all-button-text-color',
        'title'     => __( 'Reset All Button Text Color', 'ultimate-slider' )
      )
    );

    $sap->add_setting(
      'ewd-uwcf-settings',
      'ewd-uwcf-styling-widget-and-shortcode',
      'colorpicker',
      array(
        'id'      => 'styling-reset-all-button-hover-bg-color',
        'title'     => __( 'Reset All Button Hover Background Color', 'ultimate-slider' )
      )
    );

    $sap->add_setting(
      'ewd-uwcf-settings',
      'ewd-uwcf-styling-widget-and-shortcode',
      'colorpicker',
      array(
        'id'      => 'styling-reset-all-button-hover-text-color',
        'title'     => __( 'Reset All Button Hover Text Color', 'ultimate-slider' )
      )
    );

    $sap->add_setting(
      'ewd-uwcf-settings',
      'ewd-uwcf-styling-widget-and-shortcode',
      'text',
      array(
        'id'            => 'styling-reset-all-button-font-size',
        'title'         => __( 'Reset All Button Font Size', 'color-filters' ),
        'description' => ''
      )
    );

    $sap->add_section(
      'ewd-uwcf-settings',
      array_merge(
        array(
          'id'            => 'ewd-uwcf-styling-shop-thumbnails',
          'title'         => __( 'Shop Thumbnails', 'color-filters' ),
          'tab'         => 'ewd-uwcf-styling-tab',
        ),
        $this->get_permission( 'styling' )
      )
    );

    $sap->add_setting(
      'ewd-uwcf-settings',
      'ewd-uwcf-styling-shop-thumbnails',
      'colorpicker',
      array(
        'id'      => 'styling-shop-thumbnails-font-color',
        'title'     => __( 'Font Options Color', 'ultimate-slider' )
      )
    );

    $sap->add_setting(
      'ewd-uwcf-settings',
      'ewd-uwcf-styling-shop-thumbnails',
      'text',
      array(
        'id'            => 'styling-shop-thumbnails-font-size',
        'title'         => __( 'Font Options Font Size', 'color-filters' ),
        'description' => ''
      )
    );

    $sap->add_setting(
      'ewd-uwcf-settings',
      'ewd-uwcf-styling-shop-thumbnails',
      'text',
      array(
        'id'            => 'styling-shop-thumbnails-color-icon-size',
        'title'         => __( 'Color Icons Width', 'color-filters' ),
        'description' => ''
      )
    );
    
    return $sap;
  }

}
}