<?php
if ( ! defined( 'ABSPATH' ) ) exit;

if ( !class_exists( 'ewduwpmEWDPHSettings' ) ) {
class ewduwpmEWDPHSettings {

  public function __construct() {

    add_filter( 'ewd_uwpm_defaults', array( $this, 'ewd_uwpm_settings_set_defaults' ), 10, 2 );

    add_filter( 'ewd_uwpm_settings_page', array( $this, 'ewd_uwpm_settings__non_premium_tabs' ), 10, 2 );

    add_filter( 'ewd_uwpm_settings_page', array( $this, 'ewd_uwpm_settings_send_events_tab' ), 10, 2 );
  }

  public function get_permission( $permission_type = '' ) {
    global $ewd_uwpm_controller;
  
    $ewd_uwpm_premium_permissions = array();
  
    if ( ! $ewd_uwpm_controller->permissions->check_permission( $permission_type ) ) {
      $ewd_upcp_premium_permissions = array(
        'disabled'    => true,
        'disabled_image'=> '#',
        'purchase_link' => 'https://www.etoilewebdesign.com/plugins/ultimate-wp-mail/?utm_source=uwpm_lockbox'
      );
    }
  
    return $ewd_uwpm_premium_permissions;
  }

  public function ewd_uwpm_settings_set_defaults( $defaults, $ewduwpmSettings = null ) {

    $defaults = array_merge(
      $defaults,
      array(
        // Any default which you are certain that won't be used for free version.
      )
    );
  
    return $defaults;
  }

  public function ewd_uwpm_settings__non_premium_tabs( $sap, $ewduwpmSettings = null ) {

    return $sap;
  }

  // "Send Events" Tab
  public function ewd_uwpm_settings_send_events_tab( $sap, $ewduwpmSettings = null ) {
    global $ewd_uwpm_controller;

    if ( empty( $ewduwpmSettings ) ) { return $sap; }
    
    if ( empty( $ewd_uwpm_controller->permissions->check_permission( 'sms' ) ) ) { return $sap; }

    $sms_options = array();

    $args = array(
      'post_type'     => EWD_UWPM_SMS_POST_TYPE,
      'numberposts'   => -1,
      'cache_results' => false
    );

    $sms_posts = get_posts( $args );

    foreach ( $sms_posts as $sms_post ) { 

      $sms_options[ $sms_post->ID ] = $sms_post->post_title;
    }

    $sap->pages['ewd-uwpm-settings']->sections['ewd-uwpm-send-events']->settings['send-actions']->fields['email_id']['options'] = array(
      'Emails'  => $sap->pages['ewd-uwpm-settings']->sections['ewd-uwpm-send-events']->settings['send-actions']->fields['email_id']['options'],
      'SMS'     => $sms_options,
    );

    $sap->add_setting(
      'ewd-uwpm-settings',
      'ewd-uwpm-send-events-contact',
      'text',
      array(
        'id'      => 'ultimate-purchase-email',
        'title'     => __( 'Ultimate Plan Purchase Email', 'ultimate-wp-mail' ),
        'description' => __( 'The email used to purchase your \'Ultimate\' plan subscription. Used to verify SMS requests are actually being sent from your site.', 'ultimate-wp-mail' ),
        'placeholder' => $ewduwpmSettings->defaults['ultimate-purchase-email'],
      )
    );

    $sap->add_setting(
      'ewd-uwpm-settings',
      'ewd-uwpm-send-events-contact',
      'text',
      array(
        'id'      => 'admin-sms-phone-number',
        'title'     => __( 'Admin SMS Phone Number', 'ultimate-wp-mail' ),
        'description' => __( 'The phone number for the administrator, if any SMS notifications are being sent to them.', 'ultimate-wp-mail' ),
      )
    );

    $country_phone_display_array = array();
    foreach ( $ewduwpmSettings->country_phone_array as $country_code => $country_array ) {
      $country_phone_display_array[$country_code] = $country_array['name'] . ' (+' . $country_array['code'] . ')';
    }

    $sap->add_setting(
      'ewd-uwpm-settings',
      'ewd-uwpm-send-events-contact',
      'select',
      array(
        'id'            => 'sms-country-code',
        'title'         => __( 'Country Code', 'ultimate-wp-mail' ),
        'description'   => __( 'What country code should be added to SMS reminders? If no country is specified, phone numbers for reservations should start with +XXX (a plus sign followed by the country code), followed by a space or dash, or else the number the phone number will be assumed to be North American.', 'ultimate-wp-mail' ),
        'blank_option'  => true,
        'options'       => $country_phone_display_array
      )
    );
    return $sap;
  }

}
}